@@ -54,7 +54,7 @@ test_evas_map(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED,
    Evas_Object *win, *img;
    char buf[PATH_MAX];
 
-   win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
+   win = efl_add(EFL_UI_WIN_CLASS, efl_main_loop_get(),
                  efl_text_set(efl_added, "Evas Map"),
                  efl_ui_win_autodel_set(efl_added, EINA_TRUE));
 
