@@ -176,6 +176,7 @@ test_factory(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_i
 
    evas_object_show(sc);
 
-   evas_object_resize(win, 320, 480);
+   evas_object_resize(win, 320 * elm_config_scale_get(),
+                           480 * elm_config_scale_get());
    evas_object_show(win);
 }
