@@ -1,6 +1,8 @@
 #include "main.h"
 #include "docs.h"
 
+extern char* _eolian_api_symbol;
+
 static const char *
 _get_add_star(Eolian_Function_Type ftype, Eolian_Parameter_Direction pdir)
 {
@@ -118,7 +120,7 @@ _gen_func(const Eolian_State *state, const Eolian_Function *fid,
         eina_strbuf_append_char(buf, '\n');
         eina_strbuf_free(dbuf);
      }
-   eina_strbuf_append(buf, "EOAPI ");
+   eina_strbuf_append_printf(buf, "%s %s_WEAK ", _eolian_api_symbol, _eolian_api_symbol);
    if (rtp)
      {
         if (!rtps)
@@ -225,7 +227,8 @@ eo_gen_header_gen(const Eolian_State *state, const Eolian_Class *cl,
    eina_strbuf_append_printf(buf, "#define %s %s()\n\n", mname, gname);
    eina_stringshare_del(mname);
 
-   eina_strbuf_append_printf(buf, "EWAPI const Efl_Class *%s(void) EINA_CONST;\n", gname);
+   eina_strbuf_append_printf(buf, "%s %s_WEAK const Efl_Class *%s(void) EINA_CONST;\n",
+                             _eolian_api_symbol, _eolian_api_symbol, gname);
    eina_stringshare_del(gname);
 
    /* method section */
@@ -283,8 +286,9 @@ events:
         if (!eolian_event_is_beta(ev) && evs == EOLIAN_SCOPE_PUBLIC)
           eina_strbuf_append_char(buf, '\n');
 
-        eina_strbuf_append_printf(buf, "EWAPI extern const "
-                                  "Efl_Event_Description _%s;\n\n", evn);
+        eina_strbuf_append_printf(buf, "%s %s_WEAK extern const "
+                                  "Efl_Event_Description _%s;\n\n",
+                                  _eolian_api_symbol, _eolian_api_symbol, evn);
 
         Eina_Strbuf *evdbuf = eo_gen_docs_event_gen(state, ev,
            eolian_class_c_name_get(cl));
