@@ -18,6 +18,7 @@
 using System;
 using System.Runtime.InteropServices;
 using System.ComponentModel;
+using System.Diagnostics.Contracts;
 
 using static eldbus.EldbusMessageNativeFunctions;
 
@@ -25,7 +26,7 @@ namespace eldbus
 {
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public static class EldbusMessageNativeFunctions
+internal static class EldbusMessageNativeFunctions
 {
     [DllImport(efl.Libs.Eldbus)] public static extern IntPtr
         eldbus_message_ref(IntPtr msg);
@@ -773,6 +774,7 @@ public class MessageIterator
     /// <returns>A <see cref="eldbus.MessageIterator" />.</returns>
     public eldbus.MessageIterator AppendOpenContainer(string signature)
     {
+        Contract.Requires(signature != null, nameof(signature));
         CheckHandle();
 
         IntPtr new_iter = IntPtr.Zero;
