@@ -246,10 +246,7 @@ ecore_poller_add(Ecore_Poller_Type type EINA_UNUSED,
    poller = calloc(1, sizeof (Ecore_Poller));
    if (!poller) return NULL;
 
-   if (EINA_UNLIKELY(!eina_main_loop_is()))
-     {
-        EINA_MAIN_LOOP_CHECK_RETURN_VAL(NULL);
-     }
+   EINA_MAIN_LOOP_CHECK_RETURN_VAL(NULL);
 
    if (!func)
      {
