@@ -86,14 +86,12 @@ _efl_net_dialer_websocket_close_reason_check(Efl_Net_Dialer_Websocket_Close_Reas
       case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_TOO_BIG:
       case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_MISSING_EXTENSION:
       case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_SERVER_ERROR:
-      case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_IANA_REGISTRY_START:
-      case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_IANA_REGISTRY_END:
-      case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PRIVATE_START:
-      case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_PRIVATE_END:
          return EINA_TRUE;
       case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_NO_REASON:
       case EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_ABRUPTLY:
          return EINA_FALSE;
+      default:
+         break;
      }
 
    if ((r >= EFL_NET_DIALER_WEBSOCKET_CLOSE_REASON_IANA_REGISTRY_START) &&
