@@ -317,15 +317,6 @@ EAPI void *edje_object_signal_callback_seat_data_get(void);
  *
  * @brief Functions to manipulate audio abilities in edje.
  *
- * Perspective is a graphical tool that makes objects represented in 2D
- * look like they have a 3D appearance.
- *
- * Edje allows us to use perspective on any edje object. This group of
- * functions deal with the use of perspective, by creating and configuring
- * a perspective object that must set to a edje object or a canvas,
- * affecting all the objects inside that have no particular perspective
- * set already.
- *
  * @{
  */
 
@@ -817,6 +808,7 @@ struct _Edje_External_Param_Info
 
 #define EDJE_EXTERNAL_PARAM_INFO_SENTINEL {NULL, 0, 0, {.s = {NULL, NULL, NULL}}}
 
+/** Version of the EDJE External ABI used by this library .*/
 #define EDJE_EXTERNAL_TYPE_ABI_VERSION (3)
 
 /**
@@ -869,6 +861,7 @@ struct _Edje_External_Type
   Edje_External_Param_Info *parameters_info; /**< An array of #Edje_External_Param_Info describing the different parameters this EXTERNAL may have. The last element in the array must be #EDJE_EXTERNAL_PARAM_INFO_SENTINEL. */
   void                     *data; /**< Private user data that will be passed to all of the class functions. */
 };
+/** Alias for _Edje_External_Type */
 typedef struct _Edje_External_Type Edje_External_Type;
 
 /**
@@ -882,6 +875,7 @@ struct _Edje_External_Type_Info
    const Edje_External_Type *info; /**< The type definition. */
 };
 
+/** Alias for _Edje_External_Type_Info */
 typedef struct _Edje_External_Type_Info Edje_External_Type_Info;
 
 /**
@@ -1207,22 +1201,6 @@ typedef enum _Edje_Aspect_Control
  */
 EAPI const char *edje_object_part_object_name_get(const Evas_Object *obj);
 
-#ifdef EFL_BETA_API_SUPPORT
-
-/**
- * @brief Creates scene and root node which contains all 3D parts of edje object.
- * @param obj An edje part object
- * @param root node to collect all 3D parts
- * @param scene
- * @return scene and root node which contains all 3D parts of edje object
- * @note If this function returns @c EINA_FALSE, @p the scene or the root
- * node wasn't made
- * @since 1.18
- */
-EAPI Eina_Bool edje_3d_object_add(Evas_Object *obj, Eo **root_node, Eo *scene);
-
-#endif
-
 /**
  * @}
  */
@@ -1474,6 +1452,16 @@ EAPI void edje_password_show_last_timeout_set(double password_show_last_timeout)
  */
 EAPI Eina_Bool    edje_color_class_set            (const char *color_class, int r, int g, int b, int a, int r2, int g2, int b2, int a2, int r3, int g3, int b3, int a3);
 
+/**
+ * @brief Applies changes mad when setting Edje color classes.
+ *
+ * This forces all changes to color classes made by (for example)
+ * edje_color_class_set() to actually take effect.
+ * 
+ * @since 1.26
+ */
+EAPI void         edje_color_class_apply          (void);
+
 /**
  * @brief Gets Edje color class.
  *
@@ -1819,6 +1807,37 @@ EAPI Eina_List        *edje_mmap_collection_list(Eina_File *f);
  */
 EAPI void              edje_mmap_collection_list_free(Eina_List *lst);
 
+/**
+ * @brief Returns a list of colorclasses used in this edje file
+ * @param f The mapped file
+ *
+ * @return A list of strings freed by edje_file_color_class_used_free()
+ *
+ * @since 1.26
+ */
+EAPI Eina_List        *edje_mmap_color_class_used_list(Eina_File *f);
+
+/**
+ * @brief Returns a list of colorclasses used in this edje file
+ * @param file The file path
+ *
+ * @return A list of strings freed by edje_file_color_class_used_free()
+ *
+ * @since 1.26
+ */
+EAPI Eina_List        *edje_file_color_class_used_list(const char *file);
+
+/**
+ * @brief Frees a list of color classes used
+ * @param The list
+ *
+ * This frees the list returned by edje_mmap_color_class_used_list() or 
+ * edje_file_color_class_used_list() when you no longer need it.
+ *
+ * @since 1.26
+ */
+EAPI void              edje_file_color_class_used_free(Eina_List *lst);
+
 /**
  * @brief Determines whether a group matching glob exists in an edje mapped file.
  * @param f The mapped file
@@ -1831,13 +1850,14 @@ EAPI Eina_Bool         edje_mmap_group_exists(Eina_File *f, const char *glob);
 /**
  * @brief Determines whether a group have 3D Scene.
  * @param f The mapped file
- * @param glob The group name
+ * @param group The group name
  *
  * @return @c 1 if a Scene is found is found, @c 0 otherwise
  *
+ * @deprecated
  * @since 1.18
  */
-EAPI Eina_Bool         edje_mmap_3d_has(Eina_File *f, const char *group);
+EINA_DEPRECATED EAPI Eina_Bool         edje_mmap_3d_has(Eina_File *f, const char *group);
 
 /**
  * @brief Iterates over all the opened Edje files.
@@ -1952,7 +1972,13 @@ typedef enum _Edje_Action_Type
    EDJE_ACTION_TYPE_PHYSICS_ROT_SET          = 23, /**< @since 1.8 @brief Physics rotation set action value */
    EDJE_ACTION_TYPE_VIBRATION_SAMPLE         = 24, /**< @since 1.10 @brief vibration sample action value */
    EDJE_ACTION_TYPE_MO                       = 25, /**< @since 1.15 @brief Mo action value */
-   EDJE_ACTION_TYPE_LAST                     = 26  /**< Last action value */
+   EDJE_ACTION_TYPE_VG_ANIM_STOP             = 26, /** @since 1.24 @brief Vector animation stop action value */
+   EDJE_ACTION_TYPE_VG_ANIM_PAUSE            = 27, /** @since 1.24 @brief Vector animation pause action value */
+   EDJE_ACTION_TYPE_VG_ANIM_RESUME           = 28, /** @since 1.24 @brief Vector animation resume action value */
+   EDJE_ACTION_TYPE_VG_ANIM_PLAY             = 29, /** @since 1.24 @brief Vector animation play action value */
+   EDJE_ACTION_TYPE_VG_ANIM_REWIND           = 30, /** @since 1.24 @brief Vector animation rewind action value */
+   EDJE_ACTION_TYPE_VG_ANIM_LOOP             = 31, /** @since 1.24 @brief Vector animation loop value */
+   EDJE_ACTION_TYPE_LAST                     = 32  /**< Last action value */
 } Edje_Action_Type;
 
 /**
