@@ -580,7 +580,7 @@ eina_list_shutdown(void)
  *                                   API                                      *
  *============================================================================*/
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_append(Eina_List *list, const void *data)
 {
    Eina_List *l, *new_l;
@@ -614,7 +614,7 @@ on_error:
 #endif
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_prepend(Eina_List *list, const void *data)
 {
    Eina_List *new_l;
@@ -645,7 +645,7 @@ on_error:
 #endif
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_append_relative(Eina_List *list,
                           const void *data,
                           const void *relative)
@@ -666,7 +666,7 @@ eina_list_append_relative(Eina_List *list,
    return eina_list_append(list, data);
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_append_relative_list(Eina_List *list,
                                const void *data,
                                Eina_List *relative)
@@ -700,7 +700,7 @@ eina_list_append_relative_list(Eina_List *list,
    return list;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_prepend_relative(Eina_List *list,
                            const void *data,
                            const void *relative)
@@ -720,7 +720,7 @@ eina_list_prepend_relative(Eina_List *list,
    return eina_list_prepend(list, data);
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_prepend_relative_list(Eina_List *list,
                                 const void *data,
                                 Eina_List *relative)
@@ -753,7 +753,7 @@ eina_list_prepend_relative_list(Eina_List *list,
    return new_l;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_sorted_insert(Eina_List *list, Eina_Compare_Cb func, const void *data)
 {
    Eina_List *lnear;
@@ -769,7 +769,7 @@ eina_list_sorted_insert(Eina_List *list, Eina_Compare_Cb func, const void *data)
      return eina_list_prepend_relative_list(list, data, lnear);
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_remove(Eina_List *list, const void *data)
 {
    Eina_List *l;
@@ -782,7 +782,7 @@ eina_list_remove(Eina_List *list, const void *data)
    return eina_list_remove_list(list, l);
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_remove_list(Eina_List *list, Eina_List *remove_list)
 {
    Eina_List *return_l;
@@ -819,7 +819,7 @@ eina_list_remove_list(Eina_List *list, Eina_List *remove_list)
    return return_l;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_free(Eina_List *list)
 {
    Eina_List *l, *free_l;
@@ -841,7 +841,7 @@ eina_list_free(Eina_List *list)
    return NULL;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_promote_list(Eina_List *list, Eina_List *move_list)
 {
    if (!list)
@@ -885,7 +885,7 @@ eina_list_promote_list(Eina_List *list, Eina_List *move_list)
    return move_list;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_demote_list(Eina_List *list, Eina_List *move_list)
 {
    if (!list)
@@ -924,7 +924,7 @@ eina_list_demote_list(Eina_List *list, Eina_List *move_list)
    return list;
 }
 
-EAPI void *
+EINA_API void *
 eina_list_data_find(const Eina_List *list, const void *data)
 {
    if (eina_list_data_find_list(list, data))
@@ -933,7 +933,7 @@ eina_list_data_find(const Eina_List *list, const void *data)
    return NULL;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_list_move(Eina_List **to, Eina_List **from, void *data)
 {
    Eina_List *l;
@@ -954,7 +954,7 @@ eina_list_move(Eina_List **to, Eina_List **from, void *data)
    return EINA_TRUE;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_list_move_list(Eina_List **to, Eina_List **from, Eina_List *data)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(to, EINA_FALSE);
@@ -971,7 +971,7 @@ eina_list_move_list(Eina_List **to, Eina_List **from, Eina_List *data)
    return EINA_TRUE;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_data_find_list(const Eina_List *list, const void *data)
 {
    const Eina_List *l;
@@ -990,7 +990,7 @@ eina_list_data_find_list(const Eina_List *list, const void *data)
    return NULL;
 }
 
-EAPI void *
+EINA_API void *
 eina_list_nth(const Eina_List *list, unsigned int n)
 {
    Eina_List *l;
@@ -1002,7 +1002,7 @@ eina_list_nth(const Eina_List *list, unsigned int n)
    return l ? l->data : NULL;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_nth_list(const Eina_List *list, unsigned int n)
 {
    const Eina_List *l;
@@ -1038,7 +1038,7 @@ eina_list_nth_list(const Eina_List *list, unsigned int n)
    abort();
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_reverse(Eina_List *list)
 {
    Eina_List *l1, *l2;
@@ -1068,7 +1068,7 @@ eina_list_reverse(Eina_List *list)
    return list;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_reverse_clone(const Eina_List *list)
 {
    const Eina_List *l;
@@ -1088,7 +1088,7 @@ eina_list_reverse_clone(const Eina_List *list)
    return lclone;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_clone(const Eina_List *list)
 {
    const Eina_List *l;
@@ -1108,7 +1108,7 @@ eina_list_clone(const Eina_List *list)
    return lclone;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_sort(Eina_List *list, unsigned int limit, Eina_Compare_Cb func)
 {
    unsigned int i = 0;
@@ -1178,7 +1178,7 @@ eina_list_sort(Eina_List *list, unsigned int limit, Eina_Compare_Cb func)
    return list;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_shuffle(Eina_List *list, Eina_Random_Cb func)
 {
    unsigned int n, i, j;
@@ -1261,7 +1261,7 @@ eina_list_shuffle(Eina_List *list, Eina_Random_Cb func)
    return shuffled_list;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_merge(Eina_List *left, Eina_List *right)
 {
    unsigned int n_left, n_right;
@@ -1312,7 +1312,7 @@ eina_list_merge(Eina_List *left, Eina_List *right)
 }
 
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_split_list(Eina_List *list, Eina_List *relative, Eina_List **right)
 {
    Eina_List *next;
@@ -1358,7 +1358,7 @@ eina_list_split_list(Eina_List *list, Eina_List *relative, Eina_List **right)
    return list;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_sorted_merge(Eina_List *left, Eina_List *right, Eina_Compare_Cb func)
 {
    Eina_List *ret;
@@ -1435,7 +1435,7 @@ eina_list_sorted_merge(Eina_List *left, Eina_List *right, Eina_Compare_Cb func)
    return ret;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_search_sorted_near_list(const Eina_List *list,
                                   Eina_Compare_Cb func,
                                   const void *data,
@@ -1518,7 +1518,7 @@ end:
    return (Eina_List *)ct;
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_search_sorted_list(const Eina_List *list,
                              Eina_Compare_Cb func,
                              const void *data)
@@ -1537,7 +1537,7 @@ eina_list_search_sorted_list(const Eina_List *list,
 }
 
 
-EAPI void *
+EINA_API void *
 eina_list_search_sorted(const Eina_List *list,
                         Eina_Compare_Cb func,
                         const void *data)
@@ -1545,7 +1545,7 @@ eina_list_search_sorted(const Eina_List *list,
    return eina_list_data_get(eina_list_search_sorted_list(list, func, data));
 }
 
-EAPI Eina_List *
+EINA_API Eina_List *
 eina_list_search_unsorted_list(const Eina_List *list,
                                Eina_Compare_Cb func,
                                const void *data)
@@ -1561,7 +1561,7 @@ eina_list_search_unsorted_list(const Eina_List *list,
    return NULL;
 }
 
-EAPI void *
+EINA_API void *
 eina_list_search_unsorted(const Eina_List *list,
                           Eina_Compare_Cb func,
                           const void *data)
@@ -1570,7 +1570,7 @@ eina_list_search_unsorted(const Eina_List *list,
 }
 
 
-EAPI Eina_Iterator *
+EINA_API Eina_Iterator *
 eina_list_iterator_new(const Eina_List *list)
 {
    Eina_Iterator_List *it;
@@ -1593,7 +1593,7 @@ eina_list_iterator_new(const Eina_List *list)
    return &it->iterator;
 }
 
-EAPI Eina_Iterator *
+EINA_API Eina_Iterator *
 eina_list_iterator_reversed_new(const Eina_List *list)
 {
    Eina_Iterator_List *it;
@@ -1616,7 +1616,7 @@ eina_list_iterator_reversed_new(const Eina_List *list)
    return &it->iterator;
 }
 
-EAPI Eina_Accessor *
+EINA_API Eina_Accessor *
 eina_list_accessor_new(const Eina_List *list)
 {
    Eina_Accessor_List *ac;
@@ -1643,7 +1643,7 @@ eina_list_accessor_new(const Eina_List *list)
    return &ac->accessor;
 }
 
-EAPI int
+EINA_API int
 eina_list_data_idx(const Eina_List *list, void *data)
 {
    const Eina_List *l;
