@@ -280,7 +280,7 @@ eina_simple_xml_shutdown(void)
  *============================================================================*/
 
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_simple_xml_parse(const char *buf, unsigned buflen, Eina_Bool strip, Eina_Simple_XML_Cb func, const void *data)
 {
    const char *itr = buf, *itr_end = buf + buflen;
@@ -472,7 +472,7 @@ eina_simple_xml_parse(const char *buf, unsigned buflen, Eina_Bool strip, Eina_Si
    return EINA_TRUE;
 }
 
-EAPI const char *
+EINA_API const char *
 eina_simple_xml_tag_attributes_find(const char *buf, unsigned buflen)
 {
    const char *itr = buf, *itr_end = buf + buflen;
@@ -497,7 +497,7 @@ eina_simple_xml_tag_attributes_find(const char *buf, unsigned buflen)
    return NULL;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_simple_xml_attributes_parse(const char *buf, unsigned buflen, Eina_Simple_XML_Attribute_Cb func, const void *data)
 {
    const char *itr = buf, *itr_end = buf + buflen;
@@ -557,7 +557,7 @@ eina_simple_xml_attributes_parse(const char *buf, unsigned buflen, Eina_Simple_X
    return EINA_TRUE;
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_simple_xml_attribute_w3c_parse(const char *buf, Eina_Simple_XML_Attribute_Cb func, const void *data)
 {
    const char *end;
@@ -616,7 +616,7 @@ eina_simple_xml_attribute_w3c_parse(const char *buf, Eina_Simple_XML_Attribute_C
 
 /* Node loader *************************************************************/
 
-EAPI Eina_Simple_XML_Attribute *
+EINA_API Eina_Simple_XML_Attribute *
 eina_simple_xml_attribute_new(Eina_Simple_XML_Node_Tag *parent, const char *key, const char *value)
 {
    Eina_Simple_XML_Attribute *attr;
@@ -642,7 +642,7 @@ eina_simple_xml_attribute_new(Eina_Simple_XML_Node_Tag *parent, const char *key,
    return attr;
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_attribute_free(Eina_Simple_XML_Attribute *attr)
 {
    if (!attr)
@@ -671,7 +671,7 @@ _eina_simple_xml_node_data_free(Eina_Simple_XML_Node_Data *node)
    free(node);
 }
 
-EAPI Eina_Simple_XML_Node_Tag *
+EINA_API Eina_Simple_XML_Node_Tag *
 eina_simple_xml_node_tag_new(Eina_Simple_XML_Node_Tag *parent, const char *name)
 {
    Eina_Simple_XML_Node_Tag *n;
@@ -729,7 +729,7 @@ _eina_simple_xml_node_tag_free(Eina_Simple_XML_Node_Tag *tag)
    eina_mempool_free(_eina_simple_xml_tag_mp, tag);
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_tag_free(Eina_Simple_XML_Node_Tag *tag)
 {
    if (!tag)
@@ -774,14 +774,14 @@ _eina_simple_xml_node_data_new(Eina_Simple_XML_Node_Tag *parent, Eina_Simple_XML
    return n;
 }
 
-EAPI Eina_Simple_XML_Node_Data *
+EINA_API Eina_Simple_XML_Node_Data *
 eina_simple_xml_node_data_new(Eina_Simple_XML_Node_Tag *parent, const char *contents, size_t length)
 {
    return _eina_simple_xml_node_data_new
      (parent, EINA_SIMPLE_XML_NODE_DATA, contents, length);
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_data_free(Eina_Simple_XML_Node_Data *node)
 {
    if (!node)
@@ -796,14 +796,14 @@ eina_simple_xml_node_data_free(Eina_Simple_XML_Node_Data *node)
    _eina_simple_xml_node_data_free(node);
 }
 
-EAPI Eina_Simple_XML_Node_CData *
+EINA_API Eina_Simple_XML_Node_CData *
 eina_simple_xml_node_cdata_new(Eina_Simple_XML_Node_Tag *parent, const char *contents, size_t length)
 {
    return _eina_simple_xml_node_data_new
      (parent, EINA_SIMPLE_XML_NODE_CDATA, contents, length);
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_cdata_free(Eina_Simple_XML_Node_Data *node)
 {
    if (!node)
@@ -818,14 +818,14 @@ eina_simple_xml_node_cdata_free(Eina_Simple_XML_Node_Data *node)
    _eina_simple_xml_node_data_free(node);
 }
 
-EAPI Eina_Simple_XML_Node_Doctype_Child *
+EINA_API Eina_Simple_XML_Node_Doctype_Child *
 eina_simple_xml_node_doctype_child_new(Eina_Simple_XML_Node_Tag *parent, const char *contents, size_t length)
 {
    return _eina_simple_xml_node_data_new
      (parent, EINA_SIMPLE_XML_NODE_DOCTYPE_CHILD, contents, length);
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_doctype_child_free(Eina_Simple_XML_Node_Data *node)
 {
    if (!node)
@@ -840,14 +840,14 @@ eina_simple_xml_node_doctype_child_free(Eina_Simple_XML_Node_Data *node)
    _eina_simple_xml_node_data_free(node);
 }
 
-EAPI Eina_Simple_XML_Node_Processing *
+EINA_API Eina_Simple_XML_Node_Processing *
 eina_simple_xml_node_processing_new(Eina_Simple_XML_Node_Tag *parent, const char *contents, size_t length)
 {
    return _eina_simple_xml_node_data_new
      (parent, EINA_SIMPLE_XML_NODE_PROCESSING, contents, length);
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_processing_free(Eina_Simple_XML_Node_Data *node)
 {
    if (!node)
@@ -862,14 +862,14 @@ eina_simple_xml_node_processing_free(Eina_Simple_XML_Node_Data *node)
    _eina_simple_xml_node_data_free(node);
 }
 
-EAPI Eina_Simple_XML_Node_Doctype *
+EINA_API Eina_Simple_XML_Node_Doctype *
 eina_simple_xml_node_doctype_new(Eina_Simple_XML_Node_Tag *parent, const char *contents, size_t length)
 {
    return _eina_simple_xml_node_data_new
      (parent, EINA_SIMPLE_XML_NODE_DOCTYPE, contents, length);
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_doctype_free(Eina_Simple_XML_Node_Data *node)
 {
    if (!node)
@@ -884,14 +884,14 @@ eina_simple_xml_node_doctype_free(Eina_Simple_XML_Node_Data *node)
    _eina_simple_xml_node_data_free(node);
 }
 
-EAPI Eina_Simple_XML_Node_Comment *
+EINA_API Eina_Simple_XML_Node_Comment *
 eina_simple_xml_node_comment_new(Eina_Simple_XML_Node_Tag *parent, const char *contents, size_t length)
 {
    return _eina_simple_xml_node_data_new
      (parent, EINA_SIMPLE_XML_NODE_COMMENT, contents, length);
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_comment_free(Eina_Simple_XML_Node_Data *node)
 {
    if (!node)
@@ -1010,7 +1010,7 @@ _eina_simple_xml_node_parse(void *data, Eina_Simple_XML_Type type, const char *c
    return EINA_TRUE;
 }
 
-EAPI Eina_Simple_XML_Node_Root *
+EINA_API Eina_Simple_XML_Node_Root *
 eina_simple_xml_node_load(const char *buf, unsigned buflen, Eina_Bool strip)
 {
    Eina_Simple_XML_Node_Root *root;
@@ -1032,7 +1032,7 @@ eina_simple_xml_node_load(const char *buf, unsigned buflen, Eina_Bool strip)
    return root;
 }
 
-EAPI void
+EINA_API void
 eina_simple_xml_node_root_free(Eina_Simple_XML_Node_Root *root)
 {
    if (!root) return;
@@ -1192,7 +1192,7 @@ _eina_simple_xml_node_dump(Eina_Strbuf *buf, Eina_Simple_XML_Node *node, const c
      }
 }
 
-EAPI char *
+EINA_API char *
 eina_simple_xml_node_dump(Eina_Simple_XML_Node *node, const char *indent)
 {
    Eina_Strbuf *buf;
