@@ -35,7 +35,7 @@
  *
  * @since 1.12
  */
-EAPI Eina_Value_Struct_Desc *eina_value_util_struct_desc_new(void);
+EINA_API Eina_Value_Struct_Desc *eina_value_util_struct_desc_new(void);
 
 /**
  * @brief Creates a new #Eina_Value containing the passed parameter.
@@ -45,7 +45,7 @@ EAPI Eina_Value_Struct_Desc *eina_value_util_struct_desc_new(void);
  *
  * @since 1.12
  */
-EAPI Eina_Value *eina_value_util_time_string_new(const char *timestr);
+EINA_API Eina_Value *eina_value_util_time_string_new(const char *timestr);
 
 #include "eina_inline_value_util.x"
 
