@@ -19,6 +19,11 @@ eina_xdg_env_init(void)
    Eina_Vpath_Interface_User user;
 
    eina_vpath_resolve_snprintf(home, sizeof(home), "(:home:)/");
+   // last char is / - we won't want it
+   for (s = home; *s; s++)
+     {
+        if (s[1] == 0) s[0] = 0;
+     }
    memset(&user, 0, sizeof(Eina_Vpath_Interface_User));
 
 #define FATAL_SNPRINTF(_buf, _err, _fmt, ...) \
@@ -37,6 +42,7 @@ eina_xdg_env_init(void)
       if (!s) s = home; \
    } else s = home; \
    FATAL_SNPRINTF(_meta, "vpath string '%s' truncated - fatal", "%s\\%s", s, (char *)_dir); \
+   EINA_PATH_TO_UNIX(_meta); \
    (&user)->_meta = _meta;
 
 # define ENV_SET(_env, _meta) \
@@ -45,7 +51,8 @@ eina_xdg_env_init(void)
       s = getenv(_env); \
       if (!s) s = home; \
    } else s = home; \
-   FATAL_SNPRINTF(_meta, "vpath string '%s' truncated - fatal", "%s\\", s); \
+   FATAL_SNPRINTF(_meta, "vpath string '%s' truncated - fatal", "%s", s); \
+   EINA_PATH_TO_UNIX(_meta); \
    (&user)->_meta = _meta;
 
    ENV_DIR_SET(NULL, "Desktop", desktop);
@@ -63,7 +70,10 @@ eina_xdg_env_init(void)
    if (!(s = getenv("APPDATA")))
      user.run = NULL;
    else
-     user.run = s;
+     {
+        EINA_PATH_TO_UNIX(s);
+        user.run = s;
+     }
 #else /* _WIN32 */
 # if defined(HAVE_GETUID) && defined(HAVE_GETEUID)
 #  define ENV_HOME_SET(_env, _dir, _meta) \
