@@ -13,18 +13,20 @@ typedef struct _Eldbus_Model_Connection_Data Eldbus_Model_Connection_Data;
 struct _Eldbus_Model_Connection_Data
 {
    Eo *obj;
-   Eina_Bool is_listed : 1;
+
    Eldbus_Connection *connection;
-   Eina_Array *properties_array;
-   Eina_List *children_list;
-   Eina_List *children_promises;
-   Eina_List *count_promises;
+   Eldbus_Pending *pending;
    Eldbus_Connection_Type type;
+
+   Eina_List *childrens;
+   Eina_List *requests;
+
    Eina_Stringshare *address;
-   bool private;
    char *unique_name;
-   Eina_List *pending_list;
+
+   bool private;
+
+   Eina_Bool is_listed : 1;
 };
 
 #endif
-
