@@ -2,8 +2,6 @@
   #include "elementary_config.h"
 #endif
 
-#include <Elementary.h>
-#include "elm_widget.h"
 #include "elm_priv.h"
 
 #include "efl_access_window.eo.c"
