@@ -25,7 +25,7 @@ typedef Eo Efl_Ui_Frame_Legacy;
  */
 #define EFL_UI_FRAME_LEGACY_CLASS efl_ui_frame_legacy_class_get()
 
-EWAPI const Efl_Class *efl_ui_frame_legacy_class_get(void);
+EWAPI const Efl_Class *efl_ui_frame_legacy_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
