@@ -2,6 +2,8 @@
 # include "elementary_config.h"
 #endif
 
+#define EFL_UI_FACTORY_PROTECTED
+
 #include <Elementary.h>
 #include "elm_priv.h"
 
@@ -42,6 +44,22 @@ _factory_bind(const Eina_Hash *hash EINA_UNUSED, const void *key, void *data, vo
    return EINA_TRUE;
 }
 
+static void
+_efl_ui_layout_factory_building(void *data, const Efl_Event *event)
+{
+   Efl_Ui_Layout_Factory_Data *pd = data;
+   Efl_Gfx_Entity *ui_view = event->info;
+
+   if (pd->klass || pd->group || pd->style)
+     efl_ui_layout_theme_set(ui_view, pd->klass, pd->group, pd->style);
+
+   eina_hash_foreach(pd->bind.properties, _property_bind, ui_view);
+   eina_hash_foreach(pd->bind.factories, _factory_bind, ui_view);
+
+   efl_gfx_hint_weight_set(ui_view, EFL_GFX_HINT_EXPAND, 0);
+   efl_gfx_hint_fill_set(ui_view, EINA_TRUE, EINA_TRUE);
+}
+
 EOLIAN static Eo *
 _efl_ui_layout_factory_efl_object_constructor(Eo *obj, Efl_Ui_Layout_Factory_Data *pd)
 {
@@ -52,6 +70,8 @@ _efl_ui_layout_factory_efl_object_constructor(Eo *obj, Efl_Ui_Layout_Factory_Dat
    pd->bind.properties = eina_hash_stringshared_new(EINA_FREE_CB(eina_stringshare_del));
    pd->bind.factories = eina_hash_stringshared_new(EINA_FREE_CB(efl_unref));
 
+   efl_event_callback_add(obj, EFL_UI_FACTORY_EVENT_ITEM_BUILDING, _efl_ui_layout_factory_building, pd);
+
    return obj;
 }
 
@@ -68,40 +88,7 @@ _efl_ui_layout_factory_efl_object_destructor(Eo *obj, Efl_Ui_Layout_Factory_Data
    efl_destructor(efl_super(obj, MY_CLASS));
 }
 
-static Eina_Value
-_efl_ui_layout_factory_bind(Eo *obj EINA_UNUSED, void *data, const Eina_Value value)
-{
-   Efl_Ui_Layout_Factory_Data *pd = data;
-   Efl_Gfx_Entity *layout;
-
-   eina_value_pget(&value, &layout);
-
-   efl_ui_layout_theme_set(layout, pd->klass, pd->group, pd->style);
-
-   eina_hash_foreach(pd->bind.properties, _property_bind, layout);
-   eina_hash_foreach(pd->bind.factories, _factory_bind, layout);
-
-   evas_object_size_hint_weight_set(layout, EVAS_HINT_EXPAND, 0);
-   evas_object_size_hint_align_set(layout, EVAS_HINT_FILL, EVAS_HINT_FILL);
-
-   return value;
-}
-
-EOLIAN static Eina_Future *
-_efl_ui_layout_factory_efl_ui_factory_create(Eo *obj, Efl_Ui_Layout_Factory_Data *pd,
-                                             Efl_Model *model, Efl_Gfx_Entity *parent)
-{
-   Eina_Future *f;
-
-   f = efl_ui_factory_create(efl_super(obj, EFL_UI_LAYOUT_FACTORY_CLASS), model, parent);
-
-   return efl_future_then(obj, f,
-                          .success_type = EINA_VALUE_TYPE_OBJECT,
-                          .success = _efl_ui_layout_factory_bind,
-                          .data = pd);
-}
-
-EOLIAN static void
+EOLIAN static Eina_Error
 _efl_ui_layout_factory_efl_ui_factory_bind_factory_bind(Eo *obj EINA_UNUSED, Efl_Ui_Layout_Factory_Data *pd,
                                                         const char *key, Efl_Ui_Factory *factory)
 {
@@ -112,7 +99,7 @@ _efl_ui_layout_factory_efl_ui_factory_bind_factory_bind(Eo *obj EINA_UNUSED, Efl
    if (factory == NULL)
      {
         eina_hash_del(pd->bind.factories, ss_key, NULL);
-        return;
+        return EINA_ERROR_NO_ERROR;
      }
 
    f_old = eina_hash_set(pd->bind.factories, ss_key, efl_ref(factory));
@@ -121,13 +108,16 @@ _efl_ui_layout_factory_efl_ui_factory_bind_factory_bind(Eo *obj EINA_UNUSED, Efl
         efl_unref(f_old);
         eina_stringshare_del(ss_key);
      }
+
+   return EINA_ERROR_NO_ERROR;
 }
 
 EOLIAN static Eina_Error
 _efl_ui_layout_factory_efl_ui_property_bind_property_bind(Eo *obj EINA_UNUSED, Efl_Ui_Layout_Factory_Data *pd,
                                                           const char *key, const char *property)
 {
-   Eina_Stringshare *ss_key, *ss_prop, *ss_old;
+   Eina_Stringshare *ss_key, *ss_prop;
+   Eina_Stringshare *ss_old = NULL;
    ss_key = eina_stringshare_add(key);
 
    if (property == NULL)
@@ -142,13 +132,14 @@ _efl_ui_layout_factory_efl_ui_property_bind_property_bind(Eo *obj EINA_UNUSED, E
 
  end:
    efl_event_callback_call(obj, EFL_UI_PROPERTY_BIND_EVENT_PROPERTY_BOUND, (void*) ss_key);
-   eina_stringshare_del(ss_key);
+   // Only delete our key ref it it was already present in the property hash
+   if (ss_old) eina_stringshare_del(ss_key);
    return 0;
 }
 
 EOLIAN static void
-_efl_ui_layout_factory_theme_config(Eo *obj EINA_UNUSED, Efl_Ui_Layout_Factory_Data *pd
-                                        , const char *klass, const char *group, const char *style)
+_efl_ui_layout_factory_theme_config(Eo *obj EINA_UNUSED, Efl_Ui_Layout_Factory_Data *pd,
+                                    const char *klass, const char *group, const char *style)
 {
    eina_stringshare_replace(&pd->klass, klass);
    eina_stringshare_replace(&pd->group, group);
