@@ -14,18 +14,25 @@
   Efl_Ui_Position_Manager_List_Data *pd = efl_data_scope_get(obj, MY_CLASS);
 
 typedef struct {
-   unsigned int size;
+   Api_Callbacks callbacks;
+
    Eina_Future *rebuild_absolut_size;
+   int *size_cache;
+   Efl_Gfx_Entity *last_group;
+   Efl_Ui_Win *window;
+   Evas *canvas;
+
+   Vis_Segment prev_run;
+
    Eina_Rect viewport;
    Eina_Size2D abs_size;
    Eina_Vector2 scroll_position;
+
    Efl_Ui_Layout_Orientation dir;
-   int *size_cache;
+
+   unsigned int size;
    int average_item_size;
    int maximum_min_size;
-   Vis_Segment prev_run;
-   Efl_Gfx_Entity *last_group;
-   Api_Callbacks callbacks;
 } Efl_Ui_Position_Manager_List_Data;
 
 /*
@@ -62,6 +69,7 @@ cache_require(Eo *obj EINA_UNUSED, Efl_Ui_Position_Manager_List_Data *pd)
      }
 
    pd->size_cache = calloc(pd->size + 1, sizeof(int));
+   if (!pd->size_cache) return;
    pd->size_cache[0] = 0;
    pd->maximum_min_size = 0;
 
@@ -193,6 +201,8 @@ _position_items(Eo *obj EINA_UNUSED, Efl_Ui_Position_Manager_List_Data *pd, Vis_
    else
      geom.x -= (relevant_space_size - cache_access(obj, pd, new.start_id));
 
+   evas_event_freeze(pd->canvas);
+
    for (i = new.start_id; i < new.end_id; ++i)
      {
         Eina_Size2D size;
@@ -291,6 +301,9 @@ _position_items(Eo *obj EINA_UNUSED, Efl_Ui_Position_Manager_List_Data *pd, Vis_
 
    efl_gfx_entity_position_set(first_group, first_group_pos);
    efl_gfx_entity_size_set(first_group, first_group_size);
+
+   evas_event_thaw(pd->canvas);
+   evas_event_thaw_eval(pd->canvas);
 }
 
 
@@ -503,36 +516,35 @@ _efl_ui_position_manager_list_efl_object_invalidate(Eo *obj, Efl_Ui_Position_Man
    if (pd->rebuild_absolut_size)
      eina_future_cancel(pd->rebuild_absolut_size);
 
-   efl_ui_position_manager_data_access_v1_data_access_set(obj, NULL, NULL, NULL, NULL, NULL, NULL, 0);
+   efl_ui_position_manager_data_access_v1_data_access_set(obj, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0);
 
    efl_invalidate(efl_super(obj, MY_CLASS));
 }
 
-EOLIAN static int
-_efl_ui_position_manager_list_efl_ui_position_manager_entity_relative_item(Eo *obj EINA_UNUSED, Efl_Ui_Position_Manager_List_Data *pd, unsigned int current_id, Efl_Ui_Focus_Direction direction)
+EOLIAN static Eina_Bool
+_efl_ui_position_manager_list_efl_ui_position_manager_entity_relative_item(Eo *obj EINA_UNUSED, Efl_Ui_Position_Manager_List_Data *pd, unsigned int current_id, Efl_Ui_Focus_Direction direction, unsigned int *index)
 {
-   int new_id = current_id;
    switch(direction)
      {
         case EFL_UI_FOCUS_DIRECTION_RIGHT:
         case EFL_UI_FOCUS_DIRECTION_NEXT:
         case EFL_UI_FOCUS_DIRECTION_DOWN:
-          new_id +=  1;
-        break;
+           if (current_id + 1 >= pd->size) return EINA_FALSE;
+           current_id +=  1;
+           break;
         case EFL_UI_FOCUS_DIRECTION_LEFT:
         case EFL_UI_FOCUS_DIRECTION_PREVIOUS:
         case EFL_UI_FOCUS_DIRECTION_UP:
-          new_id -=  1;
-        break;
+           if (current_id == 0) return EINA_FALSE;
+           current_id -=  1;
+           break;
         default:
-          ERR("Uncaught case!");
-          new_id = -1;
-        break;
+           ERR("Uncaught case!");
+           return EINA_FALSE;
      }
-   if (new_id < 0 || new_id > (int)pd->size)
-     return -1;
-   else
-     return new_id;
+
+   if (index) *index = current_id;
+   return EINA_TRUE;
 }
 
 EOLIAN static int
@@ -542,7 +554,7 @@ _efl_ui_position_manager_list_efl_ui_position_manager_entity_version(Eo *obj EIN
 }
 
 EOLIAN static void
-_efl_ui_position_manager_list_efl_ui_position_manager_data_access_v1_data_access_set(Eo *obj, Efl_Ui_Position_Manager_List_Data *pd, void *obj_access_data, Efl_Ui_Position_Manager_Object_Batch_Callback obj_access, Eina_Free_Cb obj_access_free_cb, void *size_access_data, Efl_Ui_Position_Manager_Size_Batch_Callback size_access, Eina_Free_Cb size_access_free_cb, int size)
+_efl_ui_position_manager_list_efl_ui_position_manager_data_access_v1_data_access_set(Eo *obj, Efl_Ui_Position_Manager_List_Data *pd, Efl_Ui_Win *canvas, void *obj_access_data, Efl_Ui_Position_Manager_Object_Batch_Callback obj_access, Eina_Free_Cb obj_access_free_cb, void *size_access_data, Efl_Ui_Position_Manager_Size_Batch_Callback size_access, Eina_Free_Cb size_access_free_cb, int size)
 {
    // Cleanup cache first
    cache_invalidate(obj, pd);
@@ -554,6 +566,9 @@ _efl_ui_position_manager_list_efl_ui_position_manager_data_access_v1_data_access
      pd->callbacks.size.free_cb(pd->callbacks.size.data);
 
    // Set them
+   efl_replace(&pd->window, canvas);
+   efl_replace(&pd->canvas, canvas ? evas_object_evas_get(canvas) : NULL);
+
    pd->callbacks.object.data = obj_access_data;
    pd->callbacks.object.access = obj_access;
    pd->callbacks.object.free_cb = obj_access_free_cb;
