@@ -20,7 +20,7 @@ typedef Eo Efl_Ui_Textpath_Legacy;
  */
 #define EFL_UI_TEXTPATH_LEGACY_CLASS efl_ui_textpath_legacy_class_get()
 
-EWAPI const Efl_Class *efl_ui_textpath_legacy_class_get(void);
+EWAPI const Efl_Class *efl_ui_textpath_legacy_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
