@@ -20,7 +20,7 @@ typedef Eo Efl_Ui_Win_Legacy;
  */
 #define EFL_UI_WIN_LEGACY_CLASS efl_ui_win_legacy_class_get()
 
-EWAPI const Efl_Class *efl_ui_win_legacy_class_get(void);
+EWAPI const Efl_Class *efl_ui_win_legacy_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
