@@ -291,7 +291,7 @@ typedef enum
 typedef enum
 {
   ELM_OBJECT_MULTI_SELECT_MODE_DEFAULT = 0, /**< default multiple select mode */
-  ELM_OBJECT_MULTI_SELECT_MODE_WITH_CONTROL, /**< disallow mutiple selection
+  ELM_OBJECT_MULTI_SELECT_MODE_WITH_CONTROL, /**< disallow multiple selection
                                               * when clicked without control
                                               * key pressed */
   ELM_OBJECT_MULTI_SELECT_MODE_MAX /**< canary value: any value greater or equal
@@ -342,7 +342,7 @@ typedef enum
 /** Defines if the item is of any special type (has subitems or it's the index
  * of a group), or is just a simple item.
  *
- * @ingroup Elm_Genlist_Item
+ * @ingroup Elm_Genlist_Item_Group
  */
 typedef enum
 {
@@ -359,7 +359,7 @@ typedef enum
 /** Defines the type of the item part Used while updating item's parts It can
  * be used at updating multi fields.
  *
- * @ingroup Elm_Genlist_Item
+ * @ingroup Elm_Genlist_Item_Group
  */
 typedef enum
 {
@@ -371,7 +371,7 @@ typedef enum
 
 /** Defines where to position the item in the genlist.
  *
- * @ingroup Elm_Genlist_Item
+ * @ingroup Elm_Genlist_Item_Group
  */
 typedef enum
 {
@@ -389,7 +389,7 @@ typedef enum
 
 /** Defines where to position the item in the genlist.
  *
- * @ingroup Elm_Gengrid_Item
+ * @ingroup Elm_Gengrid_Item_Group
  */
 typedef enum
 {
@@ -407,7 +407,7 @@ typedef enum
 /** Defines the type of the item part Used while updating item's parts. It can
  * be used at updating multi fields.
  *
- * @ingroup Elm_Gengrid_Item
+ * @ingroup Elm_Gengrid_Item_Group
  */
 typedef enum
 {
@@ -491,6 +491,28 @@ typedef enum
   ELM_FOCUS_REGION_SHOW_ITEM /**< As an item. */
 } Elm_Focus_Region_Show_Mode;
 
+/** Possible values for the atspi bridge state.
+ *
+ * @since 1.26
+ *
+ * @ingroup Elm_Atspi_Bridge
+ */
+typedef enum
+{
+  ELM_ATSPI_BRIDGE_CONNECTED = 0, /**< when atspi bridge is ready */
+  ELM_ATSPI_BRIDGE_DISCONNECTED, /**< when atspi bridge is shutdown */
+} Elm_Atspi_Bridge_State;
+
+/** Data on event when atspi bridge state is changed
+ *
+ * @since 1.26
+ *
+ * @ingroup Elm_Atspi_Bridge
+ */
+typedef struct _Elm_Event_Atspi_Bridge_State_Changed
+{
+  Elm_Atspi_Bridge_State state;
+} Elm_Event_Atspi_Bridge_State_Changed;
 
 /**************************************************************************/
 EAPI extern int ELM_ECORE_EVENT_ETHUMB_CONNECT;
@@ -520,9 +542,15 @@ EAPI extern int ELM_EVENT_PROCESS_BACKGROUND;
  */
 EAPI extern int ELM_EVENT_PROCESS_FOREGROUND;
 
+/**
+ * Emitted when atspi bridge state is changed.
+ * @since 1.26
+ */
+EAPI extern int ELM_EVENT_ATSPI_BRIDGE_STATE_CHANGED;
+
 typedef Eina_Bool             (*Elm_Event_Cb)(void *data, Evas_Object *obj, Evas_Object *src, Evas_Callback_Type type, void *event_info); /**< Function prototype definition for callbacks on input events happening on Elementary widgets. @a data will receive the user data pointer passed to elm_object_event_callback_add(). @a src will be a pointer to the widget on which the input event took place. @a type will get the type of this event and @a event_info, the struct with details on this event. */
 
-extern EAPI double _elm_startup_time;
+EAPI extern double _elm_startup_time;
 
 #ifndef ELM_LIB_QUICKLAUNCH
 #define ELM_MAIN() int main(int argc, char **argv) { int ret__; _elm_startup_time = ecore_time_unix_get(); elm_init(argc, argv); ret__ = elm_main(argc, argv); elm_shutdown(); return ret__; } /**< macro to be used after the elm_main() function */
