@@ -125,7 +125,7 @@ _drag_done_cb(void *unused EINA_UNUSED,
    ELM_PHOTO_DATA_GET(obj, sd);
 
    elm_object_scroll_freeze_pop(obj);
-   efl_event_callback_legacy_call(obj, EFL_UI_EVENT_DRAG_END, NULL);
+   evas_object_smart_callback_call(obj, "drag,end", NULL);
    sd->drag_started = EINA_FALSE;
 }
 
@@ -189,8 +189,8 @@ _long_press_cb(void *obj)
                   _drag_done_cb, NULL))
           {
              elm_object_scroll_freeze_push(obj);
-             efl_event_callback_legacy_call
-               (obj, EFL_UI_EVENT_DRAG_START, NULL);
+             evas_object_smart_callback_call
+               (obj, "drag,start", NULL);
              sd->drag_started = EINA_TRUE;
           }
      }
