@@ -19,7 +19,7 @@ typedef Eo Elm_Widget_Item;
  */
 #define ELM_WIDGET_ITEM_CLASS elm_widget_item_class_get()
 
-EWAPI const Efl_Class *elm_widget_item_class_get(void);
+EWAPI const Efl_Class *elm_widget_item_class_get(void) EINA_CONST;
 
 /**
  * @brief Control size restriction state of an object's tooltip
@@ -677,7 +677,7 @@ EOAPI void elm_wdg_item_domain_part_text_translatable_set(Eo *obj, const char *p
  * items may/may not have the internal object so this api may return @c NULL if
  * the widget item doesn't have it. Additionally, the widget item is
  * managed/controlled by the widget, the widget item could be changed(moved,
- * resized even deleted) anytime by it's own widget's decision. So please dont'
+ * resized even deleted) anytime by it's own widget's decision. So please don't
  * change the track object as well as don't keep the track object in your side
  * as possible but get the track object at the moment you need to refer.
  * Otherwise, you need to add some callbacks to the track object to track it's
