@@ -56,6 +56,7 @@ extern int _elput_log_dom;
 # endif
 # define CRIT(...) EINA_LOG_DOM_CRIT(_elput_log_dom, __VA_ARGS__)
 #endif
+
 typedef struct _Elput_Interface
 {
    Eina_Bool (*connect)(Elput_Manager **manager, const char *seat, unsigned int tty);
@@ -246,6 +247,14 @@ struct _Elput_Device
    Eina_Bool invert_y : 1;
 };
 
+struct _Elput_Swipe_Gesture
+{
+   double dx, dy;
+   int finger_count;
+   int window;
+   Elput_Device *device;
+};
+
 struct _Elput_Manager
 {
    Elput_Interface *interface;
@@ -282,6 +291,7 @@ struct _Elput_Manager
 
    Elput_Input input;
    Eina_Bool del : 1;
+   Eina_Bool only_gesture_events : 1;
 };
 
 typedef struct _Elput_Async_Open
@@ -295,6 +305,7 @@ void _elput_input_enable(Elput_Manager *manager);
 void _elput_input_disable(Elput_Manager *manager);
 
 int _evdev_event_process(struct libinput_event *event);
+int _gesture_event_process(struct libinput_event *event);
 Elput_Device *_evdev_device_create(Elput_Seat *seat, struct libinput_device *device);
 void _evdev_device_destroy(Elput_Device *edev);
 void _evdev_keyboard_destroy(Elput_Keyboard *kbd);
@@ -308,6 +319,7 @@ Elput_Keyboard *_evdev_keyboard_get(Elput_Seat *seat);
 Elput_Touch *_evdev_touch_get(Elput_Seat *seat);
 
 extern Elput_Interface _logind_interface;
+extern Elput_Interface _root_interface;
 
 void _keyboard_keymap_update(Elput_Seat *seat);
 void _keyboard_group_update(Elput_Seat *seat);
