@@ -15,7 +15,6 @@ typedef struct _Validate_State
    Eina_Bool stable;
    Eina_Bool in_tree;
    Eina_Bool unimplemented_beta;
-   Eina_Bool verify_since;
    const char *since_ver;
 } Validate_State;
 
@@ -94,7 +93,7 @@ _validate_docstr(Eina_Stringshare *str, const Eolian_Object *info, Eina_List **r
 static Eina_Bool
 _validate_doc_since(Validate_State *vals, Eolian_Documentation *doc)
 {
-   if (!doc || !vals->stable || !vals->verify_since)
+   if (!doc || !vals->stable)
      return EINA_TRUE;
 
    if (doc->since)
@@ -286,7 +285,8 @@ _validate_typedecl(Validate_State *vals, Eolian_Typedecl *tp)
 }
 
 static Eina_Bool
-_validate_by_ref(Eolian_Type *tp, Eina_Bool by_ref, Eina_Bool move)
+_validate_by_ref(Validate_State *vals, Eolian_Type *tp, Eina_Bool by_ref,
+                 Eina_Bool move)
 {
    Eina_Bool maybe_ownable =
      database_type_is_ownable(tp->base.unit, tp, EINA_FALSE, NULL);
@@ -302,6 +302,15 @@ _validate_by_ref(Eolian_Type *tp, Eina_Bool by_ref, Eina_Bool move)
    if (tp->btype == EOLIAN_TYPE_BUILTIN_FUTURE)
      return EINA_TRUE;
 
+   if (tp->tdecl && (tp->tdecl->type == EOLIAN_TYPEDECL_STRUCT_OPAQUE))
+     {
+        if (vals->stable && !maybe_ownable && !by_ref)
+          {
+             _eo_parser_log(&tp->base, "opaque structs must be by reference");
+             return EINA_FALSE;
+          }
+     }
+
    /* not marked @move, or marked @by_ref; just validate */
    if (!move || by_ref)
       return EINA_TRUE;
@@ -323,7 +332,7 @@ _validate_type_by_ref(Validate_State *vals, Eolian_Type *tp,
    if (!_validate_type(vals, tp, by_ref, is_ret))
      return EINA_FALSE;
 
-   return _validate_by_ref(tp, by_ref, move);
+   return _validate_by_ref(vals, tp, by_ref, move);
 }
 
 static Eina_Bool
@@ -400,9 +409,9 @@ _validate_type(Validate_State *vals, Eolian_Type *tp, Eina_Bool by_ref,
                 int kwid = eo_lexer_keyword_str_to_id(tp->base.name);
                 if (kwid > KW_void)
                   tp->ownable = EINA_TRUE;
-                if (kwid == KW_hash && vals->stable)
+                if ((kwid == KW_hash || kwid == KW_list) && vals->stable)
                   {
-                     _eo_parser_log(&tp->base, "hashes not allowed in stable context");
+                     _eo_parser_log(&tp->base, "hashes and lists not allowed in stable context");
                      return EINA_FALSE;
                   }
                 Eolian_Type *itp = tp->base_type;
@@ -1247,6 +1256,17 @@ _add_composite(Eolian_Class *cl, const Eolian_Class *icl, Eina_Hash *ch)
      }
 }
 
+static void
+_add_implicit_composite(Eolian_Class *icl, Eina_Hash *ch, Eina_Bool try_tree)
+{
+   eina_hash_set(ch, &icl, icl);
+   if (!try_tree)
+     return;
+   Eina_List *l;
+   EINA_LIST_FOREACH(icl->extends, l, icl)
+     _add_implicit_composite(icl, ch, try_tree);
+}
+
 static Eina_Bool
 _db_fill_inherits(Validate_State *vals, Eolian_Class *cl, Eina_Hash *fhash,
                   Eina_Hash *errh)
@@ -1325,7 +1345,12 @@ _db_fill_inherits(Validate_State *vals, Eolian_Class *cl, Eina_Hash *fhash,
         cl->composite = eina_list_append(cl->composite, out_cl);
         succ = _db_fill_inherits(vals, out_cl, fhash, errh);
         ++ncomp;
-        eina_hash_set(ch, &out_cl, out_cl);
+        /* for each thing that is composited, we need to add the entire
+         * inheritance tree of it into composite hash to check, so e.g.
+         * class A -> composites B -> extends C does not complain about
+         * A not implementing C
+         */
+        _add_implicit_composite(out_cl, ch, out_cl->type == EOLIAN_CLASS_INTERFACE);
      }
 
    /* parent can be abstract, those are not checked for unimplemented,
@@ -1664,7 +1689,6 @@ database_validate(const Eolian_Unit *src)
       EINA_TRUE,
       !!getenv("EFL_RUN_IN_TREE"),
       !!getenv("EOLIAN_CLASS_UNIMPLEMENTED_BETA_WARN"),
-      !!getenv("EOLIAN_ENFORCE_SINCE")
    };
 
    /* do an initial pass to refill inherits */
