@@ -852,7 +852,7 @@ ethumb_file_set(Ethumb *e, const char *path, const char *key)
 
    sanitized_path = eina_file_path_sanitize(path);
    DBG("ethumb=%p, path=%s, key=%s", e, sanitized_path ? sanitized_path : "", key ? key : "");
-   if (sanitized_path && access(sanitized_path, R_OK))
+   if (sanitized_path && !eina_file_access(sanitized_path, EINA_FILE_ACCESS_MODE_READ))
      {
         free(sanitized_path);
         return EINA_FALSE;
@@ -1486,6 +1486,15 @@ _ethumb_image_load(Ethumb *e)
    int error;
    Evas_Coord w, h, ww, hh, fx, fy, fw, fh;
    Evas_Object *img;
+   struct stat st;
+
+   if (stat(e->src_path, &st) != 0) return 0;
+   if (S_ISDIR(st.st_mode) || S_ISFIFO(st.st_mode) ||
+#ifdef S_ISSOCK
+       S_ISSOCK(st.st_mode) ||
+#endif
+       S_ISBLK(st.st_mode) ||
+       S_ISCHR(st.st_mode)) return 0;
 
    img = e->img;
 
