@@ -14,6 +14,8 @@ _evas_image_class_initializer(Efl_Class *klass)
 #endif
 
    EFL_OPS_DEFINE(ops,
+      EFL_OBJECT_OP_FUNC(efl_file_loaded_get, _evas_image_efl_file_loaded_get),
+      EFL_OBJECT_OP_FUNC(efl_file_mmap_get, _evas_image_efl_file_mmap_get),
       EFL_OBJECT_OP_FUNC(efl_file_load, _evas_image_efl_file_load),
       EFL_OBJECT_OP_FUNC(efl_file_unload, _evas_image_efl_file_unload),
       EVAS_IMAGE_EXTRA_OPS
