@@ -9,8 +9,6 @@ typedef struct _Efl_Canvas_Vg_Gradient_Data         Efl_Canvas_Vg_Gradient_Data;
 typedef struct _Efl_Canvas_Vg_Interpolation         Efl_Canvas_Vg_Interpolation;
 typedef struct _Efl_Canvas_Vg_Object_Data           Efl_Canvas_Vg_Object_Data;
 
-typedef enum _Efl_Gfx_Vg_Value_Provider_Change_Flag Efl_Gfx_Vg_Value_Provider_Change_Flag;
-
 typedef struct _Vg_Cache
 {
    Eina_Hash             *vfd_hash;
@@ -37,6 +35,7 @@ typedef struct _Vg_User_Entry
 {
    int                   w; // current surface width
    int                   h; // current surface height
+   Eina_Rect             path_bounds;
    Efl_VG               *root;
 } Vg_User_Entry;
 
@@ -56,6 +55,7 @@ struct _Efl_Canvas_Vg_Object_Data
    void                      *ckeys[2];  //cache keys for first, last frames if animation
 
    Eina_Bool                  changed : 1;
+   Eina_Bool                  sync_render : 1;
 };
 
 struct _Efl_Canvas_Vg_Node_Data
@@ -131,16 +131,6 @@ struct _Efl_Canvas_Vg_Interpolation
    Eina_Point_3D skew;
 };
 
-enum _Efl_Gfx_Vg_Value_Provider_Change_Flag
-{
-   EFL_GFX_VG_VALUE_PROVIDER_CHANGE_FLAG_NONE = 0,
-   EFL_GFX_VG_VALUE_PROVIDER_CHANGE_FLAG_FILL_COLOR = 2,
-   EFL_GFX_VG_VALUE_PROVIDER_CHANGE_FLAG_STROKE_COLOR = 4,
-   EFL_GFX_VG_VALUE_PROVIDER_CHANGE_FLAG_STROKE_WIDTH = 8,
-   EFL_GFX_VG_VALUE_PROVIDER_CHANGE_FLAG_TRANSFORM_MATRIX = 16
-};
-Efl_Gfx_Vg_Value_Provider_Change_Flag efl_gfx_vg_value_provider_changed_flag_get(Eo *obj);
-
 void                        evas_cache_vg_init(void);
 void                        evas_cache_vg_shutdown(void);
 Vg_Cache_Entry*             evas_cache_vg_entry_resize(Vg_Cache_Entry *entry, int w, int h);
@@ -148,7 +138,7 @@ Vg_Cache_Entry*             evas_cache_vg_entry_create(Evas *evas, const Eina_Fi
 Efl_VG*                     evas_cache_vg_tree_get(Vg_Cache_Entry *vg_entry, unsigned int frame_num);
 void                        evas_cache_vg_entry_value_provider_update(Vg_Cache_Entry *vg_entry, Eina_List *vp_list);
 void                        evas_cache_vg_entry_del(Vg_Cache_Entry *vg_entry);
-Vg_File_Data *              evas_cache_vg_file_open(const Eina_File *file, const char *key, Evas *e);
+Vg_File_Data *              evas_cache_vg_file_open(const Eina_File *file, const char *key, Evas *e, Eina_Bool shareable);
 Eina_Bool                   evas_cache_vg_file_save(Efl_VG *root, int w, int h, const char *file, const char *key, const Efl_File_Save_Info *info);
 Eina_Bool                   evas_cache_vg_entry_file_save(Vg_Cache_Entry *vg_entry, const char *file, const char *key, const Efl_File_Save_Info *info);
 double                      evas_cache_vg_anim_duration_get(const Vg_Cache_Entry *vg_entry);
@@ -165,7 +155,7 @@ void                        efl_canvas_vg_container_blend_buffer_clear(Efl_VG *o
 static inline void
 efl_canvas_vg_object_change(Efl_Canvas_Vg_Object_Data *vd)
 {
-   if (!vd || vd->changed) return;
+   if (!vd || (vd->changed && vd->obj->changed)) return;
    vd->changed = EINA_TRUE;
    evas_object_change(vd->obj->object, vd->obj);
 }
