@@ -151,12 +151,12 @@ const DATA8 _evas_dither_128128[128][128] =
 };
 #endif /* USE_DITHER_128128 */
 
-EAPI void
+EVAS_API void
 evas_common_convert_init(void)
 {
 }
 
-EAPI Gfx_Func_Convert
+EVAS_API Gfx_Func_Convert
 evas_common_convert_func_get(DATA8 *dest, int w, int h EINA_UNUSED, int depth, DATA32 rmask, DATA32 gmask, DATA32 bmask, Convert_Pal_Mode pal_mode, int rotation)
 {
    if ((rmask == 0) && (gmask == 0) && (bmask == 0))
