@@ -65,12 +65,12 @@ struct _RGBA_Vertex
    num_active_edges++;                                                  \
 }
 
-EAPI void
+EVAS_API void
 evas_common_polygon_init(void)
 {
 }
 
-EAPI RGBA_Polygon_Point *
+EVAS_API RGBA_Polygon_Point *
 evas_common_polygon_point_add(RGBA_Polygon_Point *points, int x, int y)
 {
    RGBA_Polygon_Point *pt;
@@ -83,7 +83,7 @@ evas_common_polygon_point_add(RGBA_Polygon_Point *points, int x, int y)
    return points;
 }
 
-EAPI RGBA_Polygon_Point *
+EVAS_API RGBA_Polygon_Point *
 evas_common_polygon_points_clear(RGBA_Polygon_Point *points)
 {
    if (points)
@@ -122,7 +122,7 @@ polygon_edge_sorter(const void *a, const void *b)
    return 1;
 }
 
-EAPI void
+EVAS_API void
 evas_common_polygon_draw(RGBA_Image *dst, RGBA_Draw_Context *dc, RGBA_Polygon_Point *points, int x, int y)
 {
    RGBA_Gfx_Func      func;
@@ -326,7 +326,7 @@ evas_common_polygon_draw(RGBA_Image *dst, RGBA_Draw_Context *dc, RGBA_Polygon_Po
      }
 }
 
-EAPI void
+EVAS_API void
 evas_common_polygon_rgba_draw(RGBA_Image *dst, int ext_x, int ext_y, int ext_w, int ext_h, DATA32 col, int render_op, RGBA_Polygon_Point *points, int x, int y, RGBA_Image *mask_ie, int mask_x, int mask_y)
 {
    RGBA_Gfx_Func      func;
