@@ -35,7 +35,7 @@
  *
  * Supported OS: Windows XP.
  */
-EAPI char *strcasestr(const char *haystack, const char *needle);
+EVIL_API char *strcasestr(const char *haystack, const char *needle);
 
 /**
  * @brief Implements the strsep function which is used to separate strings.
@@ -61,7 +61,7 @@ EAPI char *strcasestr(const char *haystack, const char *needle);
  * @since 1.8
  *
  */
-EAPI char *strsep(char **stringp, const char *delim);
+EVIL_API char *strsep(char **stringp, const char *delim);
 
 /**
  * @}
