@@ -852,6 +852,10 @@ _surface_cap_cache_save()
    char cap_file_path[PATH_MAX];
    char tmp_file_name[PATH_MAX + PATH_MAX + 128];
    Eina_Tmpstr *tmp_file_path = NULL;
+#ifdef _WIN32
+   char *cap_file_path_2;
+   char *result_backslash;
+#endif
 
    /* use eet */
    if (!eet_init()) return 0;
@@ -866,7 +870,19 @@ _surface_cap_cache_save()
                                         sizeof(cap_dir_path));
 
    /* use mkstemp for writing */
+#ifdef _WIN32
+   /*
+    * get basename so that the temporary file is created in
+    * the tmp directory with eina_file_mkstemp()
+    */
+   if ((cap_file_path_2 = strrchr(cap_file_path, '/'))) cap_file_path_2++;
+   else cap_file_path_2 = cap_file_path;
+   if ((result_backslash = strrchr(cap_file_path_2, '\\')))
+     cap_file_path_2 = ++result_backslash;
+   snprintf(tmp_file_name, sizeof(tmp_file_name), "%s.XXXXXX.cache", cap_file_path_2);
+#else
    snprintf(tmp_file_name, sizeof(tmp_file_name), "%s.XXXXXX.cache", cap_file_path);
+#endif
    tmpfd = eina_file_mkstemp(tmp_file_name, &tmp_file_path);
    if (tmpfd < 0) goto error;
 
@@ -876,7 +892,12 @@ _surface_cap_cache_save()
    if (!_surface_cap_save(et)) goto error;
 
    if (eet_close(et) != EET_ERROR_NONE) goto destroyed;
+#ifdef _WIN32
+   /* no other choice on Windows: copy file from tmp dir to cache dir */
+   if (!CopyFile(tmp_file_path, cap_file_path, FALSE))
+#else
    if (rename(tmp_file_path, cap_file_path) < 0) goto destroyed;
+#endif
    eina_tmpstr_del(tmp_file_path);
    close(tmpfd);
    eet_shutdown();
@@ -3273,5 +3294,3 @@ evas_gl_common_context_restore_set(Eina_Bool enable)
 }
 
 //-----------------------------------------------------//
-
-
