@@ -18,11 +18,12 @@ struct _Evas_Engine_Info_GL_Drm
      {
         struct gbm_device *gbm;
 
-        int fd, bpp;
+        Ecore_Drm2_Device *dev;
+        int bpp;
         unsigned int rotation, depth;
         unsigned int format, flags;
 
-        void *output;
+        Ecore_Drm2_Output *output;
 
         Eina_Bool destination_alpha : 1;
         Eina_Bool vsync : 1;
