@@ -1,27 +1,17 @@
 #ifndef EVAS_ECTOR_GL_H
 #define EVAS_ECTOR_GL_H
 
-#undef EAPI
-
 #ifdef _WIN32
-# ifdef EFL_BUILD
-#  ifdef DLL_EXPORT
-#   define EAPI __declspec(dllexport)
-#  else
-#   define EAPI
-#  endif
-# else
-#  define EAPI __declspec(dllimport)
-# endif
+# define EMODAPI __declspec(dllexport)
 #else
 # ifdef __GNUC__
 #  if __GNUC__ >= 4
-#   define EAPI __attribute__ ((visibility("default")))
+#   define EMODAPI __attribute__ ((visibility("default")))
 #  else
-#   define EAPI
+#   define EMODAPI
 #  endif
 # else
-#  define EAPI
+#  define EMODAPI
 # endif
 #endif
 
@@ -29,8 +19,5 @@
 #include "evas_ector_gl_buffer.eo.h"
 #include "evas_ector_gl_image_buffer.eo.h"
 
-#undef EAPI
-#define EAPI
-
 #endif /* ! EVAS_ECTOR_GL_H */
 
