@@ -13,5 +13,7 @@ Software_Filter_Func eng_filter_displace_func_get(Evas_Filter_Command *cmd);
 Software_Filter_Func eng_filter_fill_func_get(Evas_Filter_Command *cmd);
 Software_Filter_Func eng_filter_mask_func_get(Evas_Filter_Command *cmd);
 Software_Filter_Func eng_filter_transform_func_get(Evas_Filter_Command *cmd);
+Software_Filter_Func eng_filter_grayscale_func_get(Evas_Filter_Command *cmd);
+Software_Filter_Func eng_filter_inverse_color_func_get(Evas_Filter_Command *cmd);
 
 #endif // EVAS_ENGINE_FILTER_H
