@@ -12,8 +12,8 @@
 
 # define GL_GLEXT_PROTOTYPES
 
-# if !defined(HAVE_ECORE_X_XLIB) && !defined(MESA_EGL_NO_X11_HEADERS)
-#  define MESA_EGL_NO_X11_HEADERS
+# if !defined(HAVE_ECORE_X_XLIB) && !defined(EGL_NO_X11)
+#  define EGL_NO_X11
 # endif
 
 # include <EGL/egl.h>
