@@ -1,10 +1,4 @@
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
 #include "ecore_wl2_suite.h"
-#include "../efl_check.h"
-#include <Ecore_Wl2.h>
 
 static const Efl_Test_Case etc[] =
 {
@@ -13,7 +7,7 @@ static const Efl_Test_Case etc[] =
    { "Display", ecore_wl2_test_display },
    { "Window", ecore_wl2_test_window },
    { "Input", ecore_wl2_test_input },
-   { "Surface", ecore_wl2_test_surface },
+   { "Output", ecore_wl2_test_output },
 #endif
    { NULL, NULL }
 };
