@@ -26,34 +26,25 @@
 
 #include "eina_suite.h"
 
-   START_TEST(eina_simple)
+EFL_START_TEST(eina_simple)
 {
-   fail_if(eina_init() != 2); /* one init by test suite */
-   fail_if(eina_shutdown() != 1);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_cpu)
+EFL_START_TEST(eina_cpu)
 {
-   fail_if(eina_init() != 2); /* one init by test suite */
-
    fail_if(eina_cpu_count() <= 0);
 
    eina_cpu_features_get();
 
-   fail_if(eina_shutdown() != 1);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_hamster)
+EFL_START_TEST(eina_hamster)
 {
-   fail_if(eina_init() != 2); /* one init by test suite */
-
    fail_if(eina_hamster_count() <= 0);
-
-   fail_if(eina_shutdown() != 1);
 }
-END_TEST
+EFL_END_TEST
 
 void eina_test_main(TCase *tc)
 {
