@@ -16,7 +16,7 @@ void dummy_module_shutdown(void)
 
 }
 
-EAPI int dummy_symbol = 0xbad;
+EINA_API int dummy_symbol = 0xbad;
 
 EINA_MODULE_INIT(dummy_module_init);
 EINA_MODULE_SHUTDOWN(dummy_module_shutdown);
