@@ -42,41 +42,41 @@ EFL_START_TEST(eina_test_vector2_operations)
 
 
    eina_vector2_set(&v1, x, y);
-   fail_if((v1.x != 1) || (v1.y != 2));
+   fail_if(!EINA_DBL_EQ(v1.x, 1) || !EINA_DBL_EQ(v1.y, 2));
 
    eina_vector2_array_set(&v2, arr);
-   fail_if((v2.x != 5) || (v2.y != 5));
+   fail_if(!EINA_DBL_EQ(v2.x, 5) || !EINA_DBL_EQ(v2.y, 5));
 
    eina_vector2_copy(&v1, &v2);
-   fail_if((v1.x != 5) || (v1.y != 5));
+   fail_if(!EINA_DBL_EQ(v1.x, 5) || !EINA_DBL_EQ(v1.y, 5));
 
    eina_vector2_negate(&v1, &v2);
-   fail_if((v1.x != -5) || (v1.y != -5));
+   fail_if(!EINA_DBL_EQ(v1.x, -5) || !EINA_DBL_EQ(v1.y, -5));
 
    eina_vector2_set(&v1, x, y);
    eina_vector2_add(&v3, &v1, &v2);
-   fail_if((v3.x != 6) || (v3.y != 7));
+   fail_if(!EINA_DBL_EQ(v3.x, 6) || !EINA_DBL_EQ(v3.y, 7));
 
    eina_vector2_subtract(&v3, &v2, &v1);
-   fail_if((v3.x != 4) || (v3.y != 3));
+   fail_if(!EINA_DBL_EQ(v3.x, 4) || !EINA_DBL_EQ(v3.y, 3));
 
    eina_vector2_scale(&v3, &v1, y);
-   fail_if((v3.x != 2) || (v3.y != 4));
+   fail_if(!EINA_DBL_EQ(v3.x, 2) || !EINA_DBL_EQ(v3.y, 4));
 
    res = eina_vector2_dot_product(&v1, &v2);
-   fail_if(res != 15);
+   fail_if(!EINA_DBL_EQ(res, 15));
 
    res = eina_vector2_length_get(&v2);
    fail_if((res - sqrt(50)) > DBL_EPSILON);
 
    res = eina_vector2_length_square_get(&v2);
-   fail_if(res != 50);
+   fail_if(!EINA_DBL_EQ(res, 50));
 
    res = eina_vector2_distance_get(&v2, &v1);
    fail_if((res - sqrt(25)) > DBL_EPSILON);
 
    res = eina_vector2_distance_square_get(&v2, &v1);
-   fail_if(res != 25);
+   fail_if(!EINA_DBL_EQ(res, 25));
 
    eina_vector2_normalize(&v3, &v2);
    fail_if((v3.x - v2.x / sqrt(50)) > DBL_EPSILON ||
@@ -86,10 +86,10 @@ EFL_START_TEST(eina_test_vector2_operations)
                           2, 2,
                           2, 2);
    eina_vector2_transform(&v3, &m2, &v1);
-   fail_if((v3.x != 6) || (v3.y != 6));
+   fail_if(!EINA_DBL_EQ(v3.x, 6) || !EINA_DBL_EQ(v3.y, 6));
 
    eina_vector2_transform(&v3, &m2, &v3);
-   fail_if((v3.x != 24) || (v3.y != 24));
+   fail_if(!EINA_DBL_EQ(v3.x, 24) || !EINA_DBL_EQ(v3.y, 24));
 
    eina_matrix3_values_set(&m3,
                           2, 2, 2,
@@ -97,14 +97,14 @@ EFL_START_TEST(eina_test_vector2_operations)
                           2, 2, 2);
 
    eina_vector2_homogeneous_position_transform(&v3, &m3, &v1);
-   fail_if((v3.x != 1) || (v3.y != 1));
+   fail_if(!EINA_DBL_EQ(v3.x, 1) || !EINA_DBL_EQ(v3.y, 1));
 
 
    eina_vector2_homogeneous_direction_transform(&v3, &m3, &v1);
-   fail_if((v3.x != 6) || (v3.y != 6));
+   fail_if(!EINA_DBL_EQ(v3.x, 6) || !EINA_DBL_EQ(v3.y, 6));
 
    eina_vector2_homogeneous_direction_transform(&v3, &m3, &v3);
-   fail_if((v3.x != 24) || (v3.y != 24));
+   fail_if(!EINA_DBL_EQ(v3.x, 24) || !EINA_DBL_EQ(v3.y, 24));
 
 }
 EFL_END_TEST
@@ -126,51 +126,51 @@ EFL_START_TEST(eina_test_vector3_operations)
 
 
    eina_vector3_set(&v1, x, y, z);
-   fail_if((v1.x != 1) || (v1.y != 2) || (v1.z != 3));
+   fail_if(!EINA_DBL_EQ(v1.x, 1) || !EINA_DBL_EQ(v1.y, 2) || !EINA_DBL_EQ(v1.z, 3));
 
    eina_vector3_array_set(&v2, arr);
-   fail_if((v2.x != 5) || (v2.y != 5) || (v2.z != 5));
+   fail_if(!EINA_DBL_EQ(v2.x, 5) || !EINA_DBL_EQ(v2.y, 5) || !EINA_DBL_EQ(v2.z, 5));
 
    eina_vector3_copy(&v1, &v2);
-   fail_if((v1.x != 5) || (v1.y != 5) || (v1.z != 5));
+   fail_if(!EINA_DBL_EQ(v1.x, 5) || !EINA_DBL_EQ(v1.y, 5) || !EINA_DBL_EQ(v1.z, 5));
 
    eina_vector3_negate(&v1, &v2);
-   fail_if((v1.x != -5) || (v1.y != -5), (v1.z != -5));
+   fail_if(!EINA_DBL_EQ(v1.x, -5) || !EINA_DBL_EQ(v1.y, -5) || !EINA_DBL_EQ(v1.z, -5));
 
    eina_vector3_set(&v1, x, y, z);
    eina_vector3_add(&v3, &v1, &v2);
-   fail_if((v3.x != 6) || (v3.y != 7) || v3.z != 8);
+   fail_if(!EINA_DBL_EQ(v3.x, 6) || !EINA_DBL_EQ(v3.y, 7) || !EINA_DBL_EQ(v3.z, 8));
 
    eina_vector3_subtract(&v3, &v2, &v1);
-   fail_if((v3.x != 4) || (v3.y != 3) || (v3.z != 2));
+   fail_if(!EINA_DBL_EQ(v3.x, 4) || !EINA_DBL_EQ(v3.y, 3) || !EINA_DBL_EQ(v3.z, 2));
 
    eina_vector3_scale(&v3, &v1, y);
-   fail_if((v3.x != 2) || (v3.y != 4) || (v3.z != 6));
+   fail_if(!EINA_DBL_EQ(v3.x, 2) || !EINA_DBL_EQ(v3.y, 4) || !EINA_DBL_EQ(v3.z, 6));
 
    eina_vector3_multiply(&v3, &v2, &v1);
-   fail_if((v3.x != 5) || (v3.y != 10) || (v3.z != 15));
+   fail_if(!EINA_DBL_EQ(v3.x, 5) || !EINA_DBL_EQ(v3.y, 10) || !EINA_DBL_EQ(v3.z, 15));
 
    res = eina_vector3_dot_product(&v1, &v2);
-   fail_if(res != 30);
+   fail_if(!EINA_DBL_EQ(res, 30));
 
    eina_vector3_cross_product(&v3, &v1, &v2);
-   fail_if((v3.x != -5) || (v3.y != 10) || (v3.z != -5));
+   fail_if(!EINA_DBL_EQ(v3.x, -5) || !EINA_DBL_EQ(v3.y, 10) || !EINA_DBL_EQ(v3.z, -5));
 
    eina_vector3_cross_product(&v3, &v1, &v3);
-   fail_if((v3.x != -40) || (v3.y != -10) || (v3.z != 20));
+   fail_if(!EINA_DBL_EQ(v3.x, -40) || !EINA_DBL_EQ(v3.y, -10) || !EINA_DBL_EQ(v3.z, 20));
 
 
    res = eina_vector3_length_get(&v2);
    fail_if((res - sqrt(75)) > DBL_EPSILON);
 
    res = eina_vector3_length_square_get(&v2);
-   fail_if(res != 75);
+   fail_if(!EINA_DBL_EQ(res, 75));
 
    res = eina_vector3_distance_get(&v2, &v1);
    fail_if((res - sqrt(29)) > (DBL_EPSILON * 2.0));
 
    res = eina_vector3_distance_square_get(&v2, &v1);
-   fail_if(res != 29);
+   fail_if(!EINA_DBL_EQ(res, 29));
 
    eina_vector3_normalize(&v3, &v2);
    fail_if((v3.x - v2.x / sqrt(75)) > DBL_EPSILON ||
@@ -185,10 +185,10 @@ EFL_START_TEST(eina_test_vector3_operations)
                           2, 2, 2,
                           2, 2, 2);
    eina_vector3_transform(&v3, &m3, &v1);
-   fail_if((v3.x != 12) || (v3.y != 12) || (v3.z != 12));
+   fail_if(!EINA_DBL_EQ(v3.x, 12) || !EINA_DBL_EQ(v3.y, 12) || !EINA_DBL_EQ(v3.z, 12));
 
    eina_vector3_transform(&v3, &m3, &v3);
-   fail_if((v3.x != 72) || (v3.y != 72) || (v3.z != 72));
+   fail_if(!EINA_DBL_EQ(v3.x, 72) || !EINA_DBL_EQ(v3.y, 72) || !EINA_DBL_EQ(v3.z, 72));
 
    eina_matrix4_values_set(&m4,
                           2, 2, 2, 2,
@@ -196,24 +196,24 @@ EFL_START_TEST(eina_test_vector3_operations)
                           2, 2, 2, 2,
                           2, 2, 2, 2);
    eina_vector3_homogeneous_position_transform(&v3, &m4, &v1);
-   fail_if((v3.x != 1) || (v3.y != 1) || (v3.z != 1));
+   fail_if(!EINA_DBL_EQ(v3.x, 1) || !EINA_DBL_EQ(v3.y, 1) || !EINA_DBL_EQ(v3.z, 1));
 
    eina_quaternion_set(&q, 2, 2, 2, 0);
    eina_vector3_quaternion_rotate(&v3, &v1, &q);
-   fail_if((v3.x != 25) || (v3.y != 2) || (v3.z != -21));
+   fail_if(!EINA_DBL_EQ(v3.x, 25) || !EINA_DBL_EQ(v3.y, 2) || !EINA_DBL_EQ(v3.z, -21));
 
    eina_vector3_orthogonal_projection_on_plane(&v3, &v1, &v2);
-   fail_if((v3.x != -1) || (v3.y != 0) || (v3.z != 1));
+   fail_if(!EINA_DBL_EQ(v3.x, -1) || !EINA_DBL_EQ(v3.y, 0) || !EINA_DBL_EQ(v3.z, 1));
 
    eina_vector3_plane_by_points(&q, &v3, &v1, &v2);
-   fail_if((q.x != -2) || (q.y != 4) || (q.z != -2) || (q.z > DBL_EPSILON));
+   fail_if(!EINA_DBL_EQ(q.x, -2) || !EINA_DBL_EQ(q.y, 4) || !EINA_DBL_EQ(q.z, -2) || (q.z > DBL_EPSILON));
 
    eina_vector3_homogeneous_direction_set(&v3, &q);
-   fail_if((v3.x != -2) || (v3.y != 4) || (v3.z != -2));
+   fail_if(!EINA_DBL_EQ(v3.x, -2) || !EINA_DBL_EQ(v3.y, 4) || !EINA_DBL_EQ(v3.z, -2));
 
    eina_quaternion_set(&q, 2, 2, 2, 0.5);
    eina_vector3_homogeneous_position_set(&v3, &q);
-   fail_if((v3.x != 4) || (v3.y != 4) || (v3.z != 4));
+   fail_if(!EINA_DBL_EQ(v3.x, 4) || !EINA_DBL_EQ(v3.y, 4) || !EINA_DBL_EQ(v3.z, 4));
 
    res2 = eina_vector3_equivalent(&v1, &v2);
    fail_if(res2 != EINA_FALSE);
@@ -230,10 +230,10 @@ EFL_START_TEST(eina_test_vector3_operations)
    fail_if(res2 != EINA_TRUE);
 
    eina_vector3_homogeneous_direction_transform(&v3, &m4, &v1);
-   fail_if((v3.x != 12) || (v3.y != 12) || (v3.z != 12));
+   fail_if(!EINA_DBL_EQ(v3.x, 12) || !EINA_DBL_EQ(v3.y, 12) || !EINA_DBL_EQ(v3.z, 12));
 
    eina_vector3_homogeneous_direction_transform(&v3, &m4, &v3);
-   fail_if((v3.x != 72) || (v3.y != 72) || (v3.z != 72));
+   fail_if(!EINA_DBL_EQ(v3.x, 72) || !EINA_DBL_EQ(v3.y, 72) || !EINA_DBL_EQ(v3.z, 72));
 
 }
 EFL_END_TEST
