@@ -24,8 +24,8 @@ static const Efl_Test_Case etc[] = {
   {"Eio", eio_test_init},
   {"Eio_Monitor", eio_test_monitor},
   {"Eio_Sentry", eio_test_sentry},
-  {"Eio Model", eio_model_test_file},
-  {"Eio Model Monitor", eio_model_test_monitor_add},
+  {"Efl Io Model", efl_io_model_test_file},
+  {"Efl Io Model Monitor", efl_io_model_test_monitor_add},
   {"Eio File", eio_test_file},
   {"Eio Job", eio_test_job},
 #ifdef XATTR_TEST_DIR
