@@ -6,8 +6,8 @@
 #include "efl_ui_suite.h"
 #include "eo_internal.h"
 
-EFL_CLASS_SIMPLE_CLASS(efl_ui_spotlight_manager, "efl_ui_spotlight_manager", EFL_UI_SPOTLIGHT_MANAGER_CLASS);
-EFL_CLASS_SIMPLE_CLASS(efl_ui_spotlight_indicator, "efl_ui_spotlight_indicator", EFL_UI_SPOTLIGHT_INDICATOR_CLASS);
+EFL_CLASS_SIMPLE_CLASS(efl_ui_spotlight_manager, "Efl.Ui.Spotlight.Manager", EFL_UI_SPOTLIGHT_MANAGER_CLASS);
+EFL_CLASS_SIMPLE_CLASS(efl_ui_spotlight_indicator, "Efl.Ui.Spotlight.Indicator", EFL_UI_SPOTLIGHT_INDICATOR_CLASS);
 
 static Efl_Ui_Win *win;
 static Efl_Ui_Spotlight_Container *container;
@@ -116,6 +116,7 @@ typedef struct {
   } spotlight;
   struct {
     int called;
+    Eina_Bool value;
   } animation;
   double last_position;
 } Transition_Calls;
@@ -126,7 +127,7 @@ static void
 _emit_pos(Eo *obj, double d)
 {
    printf("EMITTING %f %f\n", d, transition_calls.last_position);
-   if (d == transition_calls.last_position) return;
+   if (EINA_DBL_EQ(d, transition_calls.last_position)) return;
 
    efl_event_callback_call(obj, EFL_UI_SPOTLIGHT_MANAGER_EVENT_POS_UPDATE, &d);
    transition_calls.last_position = d;
@@ -187,7 +188,7 @@ static void
 _transition_animation_set(Eo *obj EINA_UNUSED, void *pd EINA_UNUSED, Eina_Bool animation)
 {
    transition_calls.animation.called++;
-   ck_assert_int_eq(animation, EINA_TRUE);
+   transition_calls.animation.value = animation;
 }
 
 static Eina_Bool
@@ -197,8 +198,8 @@ _transition_animation_get(Eo *obj EINA_UNUSED, void *pd EINA_UNUSED)
 }
 
 EFL_OPS_DEFINE(transition_tracker,
-  EFL_OBJECT_OP_FUNC(efl_ui_spotlight_manager_animation_enabled_set, _transition_animation_set),
-  EFL_OBJECT_OP_FUNC(efl_ui_spotlight_manager_animation_enabled_get, _transition_animation_get),
+  EFL_OBJECT_OP_FUNC(efl_ui_spotlight_manager_animated_transition_set, _transition_animation_set),
+  EFL_OBJECT_OP_FUNC(efl_ui_spotlight_manager_animated_transition_get, _transition_animation_get),
   EFL_OBJECT_OP_FUNC(efl_ui_spotlight_manager_content_add, _transition_content_add),
   EFL_OBJECT_OP_FUNC(efl_ui_spotlight_manager_content_del, _transition_content_del),
   EFL_OBJECT_OP_FUNC(efl_ui_spotlight_manager_switch_to, _transition_request_switch),
@@ -254,18 +255,18 @@ EFL_START_TEST (efl_ui_spotlight_active_index)
 }
 EFL_END_TEST
 
-EFL_START_TEST (efl_ui_smart_transition_calls)
+static void
+_verify_transition_calls(int number_of_animation_calls, Eina_Bool animation_value)
 {
    Efl_Ui_Widget *w, *w1, *w2;
-   Efl_Ui_Spotlight_Manager*t = _create_transition();
 
    w = efl_add(WIDGET_CLASS, win);
    w1 = efl_add(WIDGET_CLASS, win);
    w2 = efl_add(WIDGET_CLASS, win);
 
-   efl_ui_spotlight_manager_set(container, t);
    transition_calls.last_position = -2.0;
-   ck_assert_int_eq(transition_calls.animation.called, 1);
+   ck_assert_int_eq(transition_calls.animation.called, number_of_animation_calls);
+   ck_assert_int_eq(transition_calls.animation.value, animation_value);
    ck_assert_int_eq(transition_calls.spotlight.called, 1);
    ck_assert_ptr_eq(transition_calls.spotlight.spotlight, container);
    //We cannot verify group
@@ -343,6 +344,24 @@ EFL_START_TEST (efl_ui_smart_transition_calls)
    ck_assert_ptr_eq(transition_calls.content_del.current_page_at_call, w2);
    transition_calls.content_del.called = 0;
 }
+
+EFL_START_TEST (efl_ui_smart_transition_calls)
+{
+   Efl_Ui_Spotlight_Manager*t = _create_transition();
+   efl_ui_spotlight_manager_set(container, t);
+
+   _verify_transition_calls(2, EINA_TRUE);
+}
+EFL_END_TEST
+
+EFL_START_TEST (efl_ui_smart_transition_calls_no_animation)
+{
+   Efl_Ui_Spotlight_Manager*t = _create_transition();
+   efl_ui_spotlight_manager_set(container, t);
+   efl_ui_spotlight_animated_transition_set(container, EINA_FALSE);
+
+   _verify_transition_calls(3, EINA_FALSE);
+}
 EFL_END_TEST
 
 
@@ -384,7 +403,7 @@ _verify_indicator_calls(void)
    ck_assert_ptr_eq(indicator_calls.content_add.subobj, w);
    ck_assert_int_eq(indicator_calls.content_del.called, 0);
    ck_assert_int_eq(indicator_calls.position_update.called, 1);
-   ck_assert(indicator_calls.position_update.position == 0.0);
+   ck_assert(EINA_DBL_EQ(indicator_calls.position_update.position, 0.0));
    indicator_calls.content_add.called = 0;
    indicator_calls.position_update.called = 0;
 
@@ -395,7 +414,7 @@ _verify_indicator_calls(void)
    ck_assert_ptr_eq(indicator_calls.content_add.subobj, w1);
    ck_assert_int_eq(indicator_calls.content_del.called, 0);
    ck_assert_int_eq(indicator_calls.position_update.called, 1);
-   ck_assert(indicator_calls.position_update.position == 1.0);
+   ck_assert(EINA_DBL_EQ(indicator_calls.position_update.position, 1.0));
    indicator_calls.content_add.called = 0;
    indicator_calls.position_update.called = 0;
 
@@ -416,7 +435,7 @@ _verify_indicator_calls(void)
    ck_assert_int_eq(indicator_calls.content_del.index, 0);
    ck_assert_ptr_eq(indicator_calls.content_del.subobj, w1);
    ck_assert_int_eq(indicator_calls.position_update.called, 1);
-   ck_assert(indicator_calls.position_update.position == 0.0);
+   ck_assert(EINA_DBL_EQ(indicator_calls.position_update.position, 0.0));
    indicator_calls.content_del.called = 0;
    indicator_calls.position_update.called = 0;
 }
@@ -521,8 +540,8 @@ EFL_START_TEST (efl_ui_spotlight_test_push1)
      }
     Efl_Ui_Widget *w = efl_add(WIDGET_CLASS, win);
     efl_ui_spotlight_push(container, w);
-    ck_assert_int_eq(efl_pack_index_get(container, w), 0);
-    ck_assert_ptr_eq(efl_ui_spotlight_active_element_get(container), efl_pack_content_get(container, 0));
+    ck_assert_int_eq(efl_pack_index_get(container, w), 1);
+    ck_assert_ptr_eq(efl_ui_spotlight_active_element_get(container), efl_pack_content_get(container, 1));
 }
 EFL_END_TEST
 
@@ -537,7 +556,7 @@ EFL_START_TEST (efl_ui_spotlight_test_push2)
      }
     Efl_Ui_Widget *w = efl_add(WIDGET_CLASS, win);
     efl_ui_spotlight_push(container, w);
-    ck_assert_int_eq(efl_pack_index_get(container, w), 3);
+    ck_assert_int_eq(efl_pack_index_get(container, w), 4);
     ck_assert_ptr_eq(efl_ui_spotlight_active_element_get(container), w);
 }
 EFL_END_TEST
@@ -618,6 +637,75 @@ EFL_START_TEST (efl_ui_spotlight_test_pop3)
 }
 EFL_END_TEST
 
+EFL_START_TEST (efl_ui_spotlight_animated_transition)
+{
+   //this checks animation handing with the plain manager, there is no animation that will be played, but the flag should be preserved
+   ck_assert_int_eq(efl_ui_spotlight_animated_transition_get(container), EINA_TRUE);
+   efl_ui_spotlight_animated_transition_set(container, EINA_FALSE);
+   ck_assert_int_eq(efl_ui_spotlight_manager_animated_transition_get(efl_ui_spotlight_manager_get(container)), EINA_FALSE);
+
+   //now check with a real spotlight manager
+   efl_ui_spotlight_manager_set(container, efl_new(EFL_UI_SPOTLIGHT_FADE_MANAGER_CLASS));
+   efl_ui_spotlight_animated_transition_set(container, EINA_TRUE);
+   ck_assert_int_eq(efl_ui_spotlight_animated_transition_get(container), EINA_TRUE);
+   ck_assert_int_eq(efl_ui_spotlight_manager_animated_transition_get(efl_ui_spotlight_manager_get(container)), EINA_TRUE);
+
+   efl_ui_spotlight_animated_transition_set(container, EINA_FALSE);
+   ck_assert_int_eq(efl_ui_spotlight_animated_transition_get(container), EINA_FALSE);
+   ck_assert_int_eq(efl_ui_spotlight_manager_animated_transition_get(efl_ui_spotlight_manager_get(container)), EINA_FALSE);
+
+   Eo *manager2 = efl_new(EFL_UI_SPOTLIGHT_FADE_MANAGER_CLASS);
+   Eina_Bool animated_transition_manager;
+   efl_add(EFL_UI_SPOTLIGHT_CONTAINER_CLASS, win,
+    efl_ui_spotlight_manager_set(efl_added, manager2),
+    efl_ui_spotlight_animated_transition_set(efl_added, EINA_TRUE),
+    animated_transition_manager = efl_ui_spotlight_manager_animated_transition_get(manager2));
+   ck_assert_int_eq(animated_transition_manager, EINA_FALSE);
+   ck_assert_int_eq(efl_ui_spotlight_manager_animated_transition_get(manager2), EINA_TRUE);
+}
+EFL_END_TEST
+
+EFL_START_TEST (efl_ui_spotlight_min_max_sizing)
+{
+   Efl_Ui_Button *btn0, *btn1;
+   Eina_Size2D min, size;
+
+   btn0 = efl_add(WIDGET_CLASS, container);
+   efl_gfx_hint_size_min_set(btn0, EINA_SIZE2D(20, 200));
+
+   btn1 = efl_add(WIDGET_CLASS, container);
+   efl_gfx_hint_size_min_set(btn1, EINA_SIZE2D(200, 20));
+
+   efl_pack_end(container, btn0);
+   efl_pack_end(container, btn1);
+   min = efl_gfx_hint_size_restricted_min_get(container);
+   ck_assert_int_eq(min.w, 200);
+   ck_assert_int_eq(min.h, 200);
+
+   efl_gfx_hint_size_min_set(btn0, EINA_SIZE2D(20, 300));
+   efl_canvas_group_calculate(container);
+
+   min = efl_gfx_hint_size_restricted_min_get(container);
+   ck_assert_int_eq(min.w, 200);
+   ck_assert_int_eq(min.h, 300);
+
+   efl_gfx_hint_size_min_set(btn0, EINA_SIZE2D(20, 20));
+   efl_canvas_group_calculate(container);
+
+   min = efl_gfx_hint_size_restricted_min_get(container);
+   ck_assert_int_eq(min.w, 200);
+   ck_assert_int_eq(min.h, 20);
+
+   efl_ui_spotlight_size_set(container, EINA_SIZE2D(2000, 2000));
+
+   efl_gfx_entity_size_set(container, EINA_SIZE2D(200, 200));
+   size = efl_gfx_entity_size_get(btn0);
+   ck_assert_int_eq(size.w, 200);
+   ck_assert_int_eq(size.h, 200);
+
+}
+EFL_END_TEST
+
 static void
 spotlight_setup()
 {
@@ -644,6 +732,7 @@ void efl_ui_test_spotlight(TCase *tc)
    tcase_add_test(tc, efl_ui_spotlight_init);
    tcase_add_test(tc, efl_ui_spotlight_active_index);
    tcase_add_test(tc, efl_ui_smart_transition_calls);
+   tcase_add_test(tc, efl_ui_smart_transition_calls_no_animation);
    tcase_add_test(tc, efl_ui_smart_transition_lifetime);
    tcase_add_test(tc, efl_ui_smart_indicator_calls);
    tcase_add_test(tc, efl_ui_smart_indicator_transition_calls);
@@ -653,4 +742,6 @@ void efl_ui_test_spotlight(TCase *tc)
    tcase_add_test(tc, efl_ui_spotlight_test_pop1);
    tcase_add_test(tc, efl_ui_spotlight_test_pop2);
    tcase_add_test(tc, efl_ui_spotlight_test_pop3);
+   tcase_add_test(tc, efl_ui_spotlight_animated_transition);
+   tcase_add_test(tc, efl_ui_spotlight_min_max_sizing);
 }
