@@ -114,7 +114,7 @@ static const Simple_Test_Widget simple_widgets[] = {
   {elm_diskselector_add, "diskselector"},
   {elm_entry_add, "entry"},
   {elm_flipselector_add, "flipselector"},
-  {elm_video_add, "video"},
+//  {elm_video_add, "video"},
   {elm_spinner_add, "spinner"},
   {elm_multibuttonentry_add, "mbe"},
   {elm_fileselector_add, "fileselector"},
@@ -135,7 +135,7 @@ static const Simple_Test_Widget simple_widgets[] = {
   {elm_colorselector_add, "colorselector"},
   {_custom_colorselector_add, "colorselector2"},
   {elm_slideshow_add, "slideshow"},
-  {elm_map_add, "map"},
+//  {elm_map_add, "map"},
   {NULL, NULL},
 };
 
