@@ -19,6 +19,7 @@ static Eina_Bool buffer = EINA_FALSE;
 static Eina_Bool legacy_mode = EINA_FALSE;
 static int log_abort;
 static int log_abort_level;
+static unsigned int ts = 1;
 
 Eina_Bool abort_on_warnings = EINA_FALSE;
 
@@ -34,7 +35,7 @@ SUITE_INIT(elm)
 void
 _elm2_suite_init(void)
 {
-   if (getpid() != main_pid)
+   if (is_forked())
      {
         if (abort_on_warnings)
           fail_on_errors_setup();
@@ -50,6 +51,7 @@ _elm2_suite_init(void)
    ck_assert_int_eq(elm_init(1, args), 1);
    if (abort_on_warnings)
      fail_on_errors_setup();
+   ts = 1;
 }
 
 void
@@ -59,7 +61,7 @@ _elm_suite_shutdown(void)
    /* verify that ecore was de-initialized completely */
    ck_assert_int_eq(ecore_init(), 1);
    /* avoid slowdowns in fork mode */
-   if (getpid() != main_pid) return;
+   if (is_forked()) return;
    ck_assert_int_eq(ecore_shutdown(), 0);
 }
 
@@ -142,6 +144,20 @@ real_timer_add(double in, Ecore_Task_Cb cb, void *data)
    return ecore_timer_add(in, cb, data);
 }
 
+static Eina_Bool
+_timer_quit()
+{
+   ecore_main_loop_quit();
+   return EINA_FALSE;
+}
+
+void
+wait_timer(double in)
+{
+   ecore_timer_add(in, _timer_quit, NULL);
+   ecore_main_loop_begin();
+}
+
 static void
 _win_manual_render(void *data, const Efl_Event *event EINA_UNUSED)
  {
@@ -150,7 +166,7 @@ _win_manual_render(void *data, const Efl_Event *event EINA_UNUSED)
    ecore_loop_time_set(t + LOOP_INCREMENT);
    ecore_animator_custom_tick();
    ecore_evas_render_prepare(ecore_evas_ecore_evas_get(evas_object_evas_get(data)));
-   evas_norender(evas_object_evas_get(data));
+   evas_norender_with_updates(evas_object_evas_get(data));
 }
 
 static void
@@ -192,7 +208,7 @@ _ui_win_visibility_change(void *data EINA_UNUSED, const Efl_Event *ev)
 EFL_CLASS_SIMPLE_CLASS(efl_loop, "Efl.Loop", EFL_LOOP_CLASS)
 
 static Evas_Object *
-_elm_suite_win_create()
+_elm_suite_win_create(void)
 {
    Evas_Object *win;
    Eo *loop, *timer;
@@ -224,10 +240,19 @@ _elm_suite_win_create()
    return win;
 }
 
+#define TEST_FONT_DIR TESTS_SRC_DIR "/fonts/"
+
 Evas_Object *
-win_add()
+win_add(void)
 {
-   if (getpid() != main_pid)
+   static Eina_Bool font_path = EINA_FALSE;
+
+   if (!font_path)
+     {
+        evas_font_path_global_append(TEST_FONT_DIR);
+        font_path = EINA_TRUE;
+     }
+   if (is_forked())
      {
         if (global_win) return global_win;
      }
@@ -252,7 +277,7 @@ win_add_focused()
 {
    Evas_Object *win;
 
-   if (getpid() != main_pid)
+   if (is_forked())
      {
         if (global_win) return global_win;
      }
@@ -262,6 +287,26 @@ win_add_focused()
    return win;
 }
 
+Eina_Bool
+is_forked(void)
+{
+   return getpid() != main_pid;
+}
+
+Eina_Bool
+is_buffer(void)
+{
+   return buffer;
+}
+
+static void (*suite_setup_cb)(Eo*);
+
+void
+suite_setup_cb_set(void (*cb)(Eo*))
+{
+   suite_setup_cb = cb;
+}
+
 int
 suite_setup(Eina_Bool legacy)
 {
@@ -291,11 +336,12 @@ suite_setup(Eina_Bool legacy)
      failed_count = _efl_suite_build_and_run(0, NULL,
                                              "Efl_Ui_Init", ui_init, NULL, NULL);
 
-   failed_count += !elm_init(1, (char*[]){"exe"});
+   failed_count += !elm_init(1, args);
    if (buffer)
      {
         global_win = _elm_suite_win_create();
         force_focus_win(global_win);
+        if (suite_setup_cb) suite_setup_cb(global_win);
      }
    EINA_SAFETY_ON_TRUE_RETURN_VAL(failed_count, 255);
    /* preload default theme */
@@ -420,29 +466,42 @@ attempt_to_find_the_right_point_for_mouse_positioning(Eo *obj, int dir)
 }
 
 static void
-click_object_internal(Eo *obj, int dir, int flags)
+click_object_internal(Eo *obj, int dir, int flags, Eina_Bool up)
 {
    Evas *e = evas_object_evas_get(obj);
    Eina_Position2D pos = attempt_to_find_the_right_point_for_mouse_positioning(obj, dir);
-   evas_event_feed_mouse_move(e, pos.x, pos.y, 0, NULL);
-   evas_event_feed_mouse_down(e, 1, flags, 0, NULL);
-   evas_event_feed_mouse_up(e, 1, 0, 0, NULL);
+   evas_event_feed_mouse_move(e, pos.x, pos.y, ts++, NULL);
+   evas_event_feed_mouse_down(e, 1, flags, ts++, NULL);
+   if (up)
+     evas_event_feed_mouse_up(e, 1, 0, ts++, NULL);
 }
 
 void
 click_object(Eo *obj)
 {
-   click_object_internal(obj, NONE, 0);
+   click_object_internal(obj, NONE, 0, EINA_TRUE);
+}
+
+void
+press_object(Eo *obj)
+{
+   click_object_internal(obj, NONE, 0, EINA_FALSE);
 }
 
 void
 click_object_flags(Eo *obj, int flags)
 {
-   click_object_internal(obj, NONE, flags);
+   click_object_internal(obj, NONE, flags, EINA_TRUE);
 }
 
 void
-click_part_flags(Eo *obj, const char *part, int flags)
+press_object_flags(Eo *obj, int flags)
+{
+   click_object_internal(obj, NONE, flags, EINA_FALSE);
+}
+
+static void
+click_part_flags_internal(Eo *obj, const char *part, int flags, Eina_Bool up)
 {
    Efl_Part *part_obj = efl_ref(efl_part(obj, part));
    Eo *content;
@@ -462,19 +521,39 @@ click_part_flags(Eo *obj, const char *part, int flags)
         else if (strstr(part, "bottom"))
           dir |= BOTTOM;
      }
-   click_object_internal(content, dir, flags);
+   click_object_internal(content, dir, flags, up);
    if (efl_isa(content, EFL_LAYOUT_SIGNAL_INTERFACE))
      edje_object_message_signal_process(content);
-   edje_object_message_signal_process(obj);
+   /* can be false if obj is an elm_widget_item */
+   if (efl_isa(obj, EFL_LAYOUT_SIGNAL_INTERFACE))
+     edje_object_message_signal_process(obj);
    efl_unref(part_obj);
 }
 
+void
+click_part_flags(Eo *obj, const char *part, int flags)
+{
+   click_part_flags_internal(obj, part, flags, EINA_TRUE);
+}
+
+void
+press_part_flags(Eo *obj, const char *part, int flags)
+{
+   click_part_flags_internal(obj, part, flags, EINA_FALSE);
+}
+
 void
 click_part(Eo *obj, const char *part)
 {
    click_part_flags(obj, part, 0);
 }
 
+void
+press_part(Eo *obj, const char *part)
+{
+   press_part_flags(obj, part, 0);
+}
+
 static void
 wheel_object_internal(Eo *obj, int dir, Eina_Bool horiz, Eina_Bool down)
 {
@@ -521,6 +600,7 @@ event_callback_single_call_int_data(void *data, Evas_Object *obj EINA_UNUSED, vo
 {
    int *called = data;
 
+   if (*called) fprintf(stderr, "TEST FAILURE IN %s\n", __func__);
    ck_assert_int_eq(*called, 0);
    *called = 1;
 }
@@ -539,22 +619,89 @@ event_callback_that_quits_the_main_loop_when_called()
    ecore_main_loop_quit();
 }
 
+void
+smart_callback_that_stores_event_info_to_data(void *data, Evas_Object *obj EINA_UNUSED, void *event_info)
+{
+   void **real_data = data;
+
+   *real_data = event_info;
+}
+
 void
 click_object_at(Eo *obj, int x, int y)
 {
    Evas *e = evas_object_evas_get(obj);
-   evas_event_feed_mouse_move(e, x, y, 0, NULL);
-   evas_event_feed_mouse_down(e, 1, 0, 0, NULL);
-   evas_event_feed_mouse_up(e, 1, 0, 0, NULL);
+   evas_event_feed_mouse_move(e, x, y, ts++, NULL);
+   evas_event_feed_mouse_down(e, 1, 0, ts++, NULL);
+   evas_event_feed_mouse_up(e, 1, 0, ts++, NULL);
+}
+
+void
+multi_click_object(Eo *obj, int ids)
+{
+   Evas *e = evas_object_evas_get(obj);
+   Eina_Position2D pos = attempt_to_find_the_right_point_for_mouse_positioning(obj, NONE);
+   for (int i = 0; i < ids; i++)
+     evas_event_feed_multi_down(e, i, pos.x + i, pos.y + i, 1, 1, 1, 1, 0, pos.x + i, pos.y + i, 0, ts, NULL);
+   ts++;
+   for (int i = 0; i < ids; i++)
+     evas_event_feed_multi_up(e, i, pos.x + i, pos.y + i, 1, 1, 1, 1, 0, pos.x + i, pos.y + i, 0, ts, NULL);
+}
+
+void
+multi_press_object(Eo *obj, int ids)
+{
+   Evas *e = evas_object_evas_get(obj);
+   Eina_Position2D pos = attempt_to_find_the_right_point_for_mouse_positioning(obj, NONE);
+   for (int i = 0; i < ids; i++)
+     evas_event_feed_multi_down(e, i, pos.x + i, pos.y + i, 1, 1, 1, 1, 0, pos.x + i, pos.y + i, 0, ts, NULL);
+   ts++;
+}
+
+void
+multi_click_object_at(Eo *obj, int x, int y, int ids)
+{
+   Evas *e = evas_object_evas_get(obj);
+   for (int i = 0; i < ids; i++)
+     evas_event_feed_multi_down(e, i, x + i, y + i, 1, 1, 1, 1, 0, x + i, y + i, 0, ts, NULL);
+   ts++;
+   for (int i = 0; i < ids; i++)
+     evas_event_feed_multi_up(e, i, x + i, y + i, 1, 1, 1, 1, 0, x + i, y + i, 0, ts, NULL);
+   ts++;
+}
+
+void
+press_object_at(Eo *obj, int x, int y)
+{
+   Evas *e = evas_object_evas_get(obj);
+   evas_event_feed_mouse_move(e, x, y, ts++, NULL);
+   evas_event_feed_mouse_down(e, 1, 0, ts++, NULL);
+}
+
+void
+multi_press_object_at(Eo *obj, int x, int y, int ids)
+{
+   Evas *e = evas_object_evas_get(obj);
+   for (int i = 0; i < ids; i++)
+     evas_event_feed_multi_down(e, i, x + i, y + i, 1, 1, 1, 1, 0, x + i, y + i, 0, ts, NULL);
+   ts++;
 }
 
 void
 click_object_at_flags(Eo *obj, int x, int y, int flags)
 {
    Evas *e = evas_object_evas_get(obj);
-   evas_event_feed_mouse_move(e, x, y, 0, NULL);
-   evas_event_feed_mouse_down(e, 1, flags, 0, NULL);
-   evas_event_feed_mouse_up(e, 1, 0, 0, NULL);
+   evas_event_feed_mouse_move(e, x, y, ts++, NULL);
+   evas_event_feed_mouse_down(e, 1, flags, ts++, NULL);
+   evas_event_feed_mouse_up(e, 1, 0, ts++, NULL);
+}
+
+void
+press_object_at_flags(Eo *obj, int x, int y, int flags)
+{
+   Evas *e = evas_object_evas_get(obj);
+   evas_event_feed_mouse_move(e, x, y, ts++, NULL);
+   evas_event_feed_mouse_down(e, 1, flags, ts++, NULL);
 }
 
 void
@@ -570,8 +717,8 @@ drag_object(Eo *obj, int x, int y, int dx, int dy, Eina_Bool iterate)
 {
    Evas *e = evas_object_evas_get(obj);
    int i;
-   evas_event_feed_mouse_move(e, x, y, 0, NULL);
-   evas_event_feed_mouse_down(e, 1, 0, 0, NULL);
+   evas_event_feed_mouse_move(e, x, y, ts++, NULL);
+   evas_event_feed_mouse_down(e, 1, 0, ts++, NULL);
    if (iterate)
      {
         /* iterate twice to trigger timers */
@@ -581,10 +728,112 @@ drag_object(Eo *obj, int x, int y, int dx, int dy, Eina_Bool iterate)
    /* create DRAG_OBJECT_NUM_MOVES move events distinct from up/down */
    for (i = 0; i < DRAG_OBJECT_NUM_MOVES; i++)
      {
-        evas_event_feed_mouse_move(e, x + (i * dx / DRAG_OBJECT_NUM_MOVES), y + (i * dy / DRAG_OBJECT_NUM_MOVES), 0, NULL);
+        evas_event_feed_mouse_move(e, x + (i * dx / DRAG_OBJECT_NUM_MOVES), y + (i * dy / DRAG_OBJECT_NUM_MOVES), ts++, NULL);
         /* also trigger smart calc if we're iterating just in case that's important */
         evas_smart_objects_calculate(e);
      }
-   evas_event_feed_mouse_move(e, x + dx, y + dy, 0, NULL);
-   evas_event_feed_mouse_up(e, 1, 0, 0, NULL);
+   evas_event_feed_mouse_move(e, x + dx, y + dy, ts++, NULL);
+   evas_event_feed_mouse_up(e, 1, 0, ts++, NULL);
+}
+
+int
+drag_object_around(Eo *obj, int cx, int cy, int radius, int degrees)
+{
+   Evas *e = evas_object_evas_get(obj);
+   /* clamp num mouse moves to a vaguely sane value */
+   int i, num = MIN(abs(degrees), DRAG_OBJECT_AROUND_NUM_MOVES);
+   int last_x = round(cx + radius);
+   int last_y = round(cy);
+   /* start at 0 degrees */
+   evas_event_feed_mouse_move(e, last_x, last_y, ts++, NULL);
+   evas_event_feed_mouse_down(e, 1, 0, ts++, NULL);
+   for (i = 1; i < num; i++)
+     {
+        /* x = cx + r * cos(a), y = cy + r * sin(a) */
+        int ax, ay;
+        /* each iteration is 1 degree */
+        double angle = (i * (degrees / DRAG_OBJECT_AROUND_NUM_MOVES)) * M_PI / 180.0;
+        ax = round(cx + radius * cos(angle));
+        ay = round(cy + radius * sin(angle));
+        if ((ax == last_x) && (ay == last_y)) continue;
+        evas_event_feed_mouse_move(e, ax, ay, ts++, NULL);
+        last_x = ax, last_y = ay;
+     }
+   evas_event_feed_mouse_up(e, 1, 0, ts++, NULL);
+   /* only count arc motion: subtract initial move, mouse down, mouse up */
+   return num;
+}
+
+int
+multi_drag_object_around(Eo *obj, int touch_point, int cx, int cy, int radius, int degrees)
+{
+   Evas *e = evas_object_evas_get(obj);
+   /* clamp num mouse moves to a vaguely sane value */
+   int i, num = MIN(abs(degrees), DRAG_OBJECT_AROUND_NUM_MOVES);
+   int last_x = round(cx + radius);
+   int last_y = round(cy);
+   /* start at 0 degrees */
+   evas_event_feed_multi_down(e, touch_point, last_x, last_y, 1, 1, 1, 1, 0, last_x, last_y, 0, ts++, NULL);
+   for (i = 1; i < num; i++)
+     {
+        /* x = cx + r * cos(a), y = cy + r * sin(a) */
+        int ax, ay;
+        /* each iteration is 1 degree */
+        double angle = (i * (degrees / DRAG_OBJECT_AROUND_NUM_MOVES)) * M_PI / 180.0;
+        ax = round(cx + radius * cos(angle));
+        ay = round(cy + radius * sin(angle));
+        if ((ax == last_x) && (ay == last_y)) continue;
+        evas_event_feed_multi_move(e, touch_point, ax, ay, 1, 1, 1, 1, 0, ax, ay, ts++, NULL);
+        last_x = ax, last_y = ay;
+     }
+   evas_event_feed_multi_up(e, touch_point, last_x, last_y, 1, 1, 1, 1, 0, last_x, last_y, 0, ts++, NULL);
+   /* only count arc motion: subtract initial move, mouse down, mouse up */
+   return num;
+}
+
+int
+pinch_object(Eo *obj, int x, int y, int x2, int y2, int dx, int dy, int dx2, int dy2)
+{
+   Evas *e = evas_object_evas_get(obj);
+   int i, idx, idy, idx2, idy2;
+   idx = idy = idx2 = idy2 = 0;
+   evas_event_feed_multi_down(e, 0, x, y, 1, 1, 1, 1, 0, x, y, 0, ts, NULL);
+   evas_event_feed_multi_down(e, 1, x2, y2, 1, 1, 1, 1, 0, x2, y2, 0, ts++, NULL);
+   for (i = 1; i < abs(dx); i++)
+     {
+        idx = (i * dx / abs(dx));
+        idy = (i * dy / abs(dx));
+        idx2 = (i * dx2 / abs(dx));
+        idy2 = (i * dy2 / abs(dx));
+        /* move first point along positive vector */
+        evas_event_feed_multi_move(e, 0, x + idx, y + idy, 1, 1, 1, 1, 0, x + idx, y + idy, ts, NULL);
+        /* move second point along negative vector */
+        evas_event_feed_multi_move(e, 1, x2 + idx2, y2 + idy2, 1, 1, 1, 1, 0, x2 + idx2, y2 + idy2, ts++, NULL);
+        /* also trigger smart calc if we're iterating just in case that's important */
+        evas_smart_objects_calculate(e);
+     }
+   evas_event_feed_multi_up(e, 0, x + idx, y + idy, 1, 1, 1, 1, 0, x + idx, y + idy, 0, ts, NULL);
+   evas_event_feed_multi_up(e, 1, x2 + idx2, y2 + idy2, 1, 1, 1, 1, 0, x2 + idx2, y2 + idy2, 0, ts++, NULL);
+   return i - 2;
+}
+
+void
+write_key_sequence(Eo *obj, const char *seqence)
+{
+  Evas *e = evas_object_evas_get(obj);
+  for (unsigned int i = 0; i < strlen(seqence); ++i)
+    {
+       const char part_seq[] = {seqence[i], '\0'};
+
+       evas_event_feed_key_down(e, part_seq, part_seq, part_seq, part_seq, 0, NULL);
+       ecore_main_loop_iterate();
+       evas_event_feed_key_up(e, part_seq, part_seq, part_seq, part_seq, 0, NULL);
+       ecore_main_loop_iterate();
+    }
+}
+
+void
+force_render(Eo *win)
+{
+   _win_manual_render(win, NULL);
 }
