@@ -2,6 +2,10 @@
 # include <config.h>
 #endif
 
+#ifdef _WIN32
+# include <evil_private.h> /* setenv unsetenv */
+#endif
+
 #include "elua_suite.h"
 #include "../efl_check.h"
 #include <Elua.h>
