@@ -4,6 +4,7 @@
 
 #include "emile_suite.h"
 #include "../efl_check.h"
+#include <Emile.h>
 
 static const Efl_Test_Case etc[] = {
   { "Emile_Base", emile_test_base },
@@ -11,6 +12,16 @@ static const Efl_Test_Case etc[] = {
   { NULL, NULL }
 };
 
+SUITE_INIT(emile)
+{
+   ck_assert_int_eq(emile_init(), 1);
+}
+
+SUITE_SHUTDOWN(emile)
+{
+   ck_assert_int_eq(emile_shutdown(), 0);
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -24,7 +35,7 @@ main(int argc, char *argv[])
 #endif
 
    failed_count = _efl_suite_build_and_run(argc - 1, (const char **)argv + 1,
-                                           "Emile", etc);
+                                           "Emile", etc, SUITE_INIT_FN(emile), SUITE_SHUTDOWN_FN(emile));
 
    return (failed_count == 0) ? 0 : 255;
 }
