@@ -7,12 +7,10 @@
 
 #include "emile_suite.h"
 
-START_TEST(emile_test_init)
+EFL_START_TEST(emile_test_init)
 {
-   fail_if(emile_init() <= 0);
-   fail_if(emile_shutdown() != 0);
 }
-END_TEST
+EFL_END_TEST
 
 void emile_test_base(TCase *tc)
 {
