@@ -11,5 +11,8 @@
 struct Generated_Future_Data {};
 typedef struct Generated_Future_Data Generated_Future_Data;
 
+#define EOTEST_API
+#define EOTEST_API_WEAK
+
 #include "generated_future.eo.h"
 #include "generated_future.eo.c"
